[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-changelog] [xen-unstable] [XEN] Remove definition of printf. All users are switched to printk.



# HG changeset patch
# User kfraser@xxxxxxxxxxxxxxxxxxxxx
# Node ID 29b02d929b7e4df6016c16ebba71d6d73462882e
# Parent  f5d179bcad704351bb0c1d4f36c20146080c79cc
[XEN] Remove definition of printf. All users are switched to printk.
Signed-off-by: Keir Fraser <keir@xxxxxxxxxxxxx>
---
 xen/arch/ia64/linux-xen/setup.c              |    2 
 xen/arch/ia64/vmx/mm.c                       |    2 
 xen/arch/ia64/vmx/mmio.c                     |   14 +--
 xen/arch/ia64/vmx/vmx_phy_mode.c             |    8 +-
 xen/arch/ia64/vmx/vmx_vcpu.c                 |    2 
 xen/arch/ia64/vmx/vmx_virt.c                 |    6 -
 xen/arch/ia64/xen/dom0_ops.c                 |    6 -
 xen/arch/ia64/xen/dom_fw.c                   |   26 +++----
 xen/arch/ia64/xen/domain.c                   |   16 ++--
 xen/arch/ia64/xen/faults.c                   |   36 +++++-----
 xen/arch/ia64/xen/fw_emul.c                  |   54 +++++++--------
 xen/arch/ia64/xen/hypercall.c                |   12 +--
 xen/arch/ia64/xen/hyperprivop.S              |    2 
 xen/arch/ia64/xen/irq.c                      |    2 
 xen/arch/ia64/xen/mm.c                       |    8 +-
 xen/arch/ia64/xen/privop.c                   |   22 +++---
 xen/arch/ia64/xen/regionreg.c                |    8 +-
 xen/arch/ia64/xen/vcpu.c                     |   96 +++++++++++++--------------
 xen/arch/ia64/xen/vhpt.c                     |    6 -
 xen/arch/ia64/xen/xenmisc.c                  |    4 -
 xen/arch/ia64/xen/xensetup.c                 |    6 -
 xen/arch/ia64/xen/xentime.c                  |    2 
 xen/arch/powerpc/backtrace.c                 |   20 ++---
 xen/arch/powerpc/domain.c                    |    8 +-
 xen/arch/powerpc/of-devwalk.c                |   18 ++---
 xen/arch/powerpc/powerpc64/domain.c          |    6 -
 xen/arch/x86/boot/x86_32.S                   |    2 
 xen/arch/x86/boot/x86_64.S                   |    2 
 xen/arch/x86/hvm/hvm.c                       |    2 
 xen/arch/x86/hvm/io.c                        |    2 
 xen/arch/x86/hvm/platform.c                  |    6 +
 xen/arch/x86/hvm/svm/intr.c                  |    2 
 xen/arch/x86/hvm/svm/svm.c                   |   38 +++++-----
 xen/arch/x86/hvm/svm/vmcb.c                  |   36 +++++-----
 xen/arch/x86/hvm/vmx/vmx.c                   |    4 -
 xen/arch/x86/setup.c                         |    2 
 xen/arch/x86/x86_32/entry.S                  |    2 
 xen/arch/x86/x86_32/supervisor_mode_kernel.S |    2 
 xen/arch/x86/x86_64/entry.S                  |    2 
 xen/common/sched_sedf.c                      |    6 -
 xen/drivers/char/console.c                   |    2 
 xen/include/asm-ia64/config.h                |    2 
 xen/include/asm-ia64/vcpu.h                  |    2 
 xen/include/xen/lib.h                        |    3 
 44 files changed, 255 insertions(+), 254 deletions(-)

diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/linux-xen/setup.c
--- a/xen/arch/ia64/linux-xen/setup.c   Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/linux-xen/setup.c   Mon Oct 23 14:42:52 2006 +0100
@@ -803,7 +803,7 @@ cpu_init (void)
        cpu_data = per_cpu_init();
 
 #ifdef XEN
-       printf ("cpu_init: current=%p\n", current);
+       printk("cpu_init: current=%p\n", current);
 #endif
 
        /*
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/vmx/mm.c
--- a/xen/arch/ia64/vmx/mm.c    Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/vmx/mm.c    Mon Oct 23 14:42:52 2006 +0100
@@ -144,7 +144,7 @@ int vmx_do_mmu_update(mmu_update_t *ureq
             gpfn = req.val;
             set_machinetophys(mfn,gpfn);
         }else{
-            printf("Unkown command of mmu_update:ptr: %lx,val: %lx 
\n",req.ptr,req.val);
+            printk("Unkown command of mmu_update:ptr: %lx,val: %lx 
\n",req.ptr,req.val);
             while(1);
         }
         ureqs ++;
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/vmx/mmio.c
--- a/xen/arch/ia64/vmx/mmio.c  Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/vmx/mmio.c  Mon Oct 23 14:42:52 2006 +0100
@@ -80,7 +80,7 @@ static void pib_write(VCPU *vcpu, void *
             }
         }
         else {      // upper half
-            printf("IPI-UHF write %lx\n",pib_off);
+            printk("IPI-UHF write %lx\n",pib_off);
             panic_domain(NULL,"Not support yet for SM-VP\n");
         }
         break;
@@ -114,7 +114,7 @@ static void pib_read(VCPU *vcpu, uint64_
             }
             else {
 #ifdef  IPI_DEBUG
-                printf("IPI-LHF read %lx\n",pib_off);
+                printk("IPI-LHF read %lx\n",pib_off);
 #endif
                 *(uint64_t *)dest = 0;  // TODO for SM-VP
             }
@@ -125,7 +125,7 @@ static void pib_read(VCPU *vcpu, uint64_
             }
             else {
 #ifdef  IPI_DEBUG
-                printf("IPI-UHF read %lx\n",pib_off);
+                printk("IPI-UHF read %lx\n",pib_off);
 #endif
                 *(uint8_t *)dest = 0;   // TODO for SM-VP
             }
@@ -321,7 +321,7 @@ static void deliver_ipi (VCPU *vcpu, uin
 static void deliver_ipi (VCPU *vcpu, uint64_t dm, uint64_t vector)
 {
 #ifdef  IPI_DEBUG
-  printf ("deliver_ipi %lx %lx\n",dm,vector);
+  printk ("deliver_ipi %lx %lx\n",dm,vector);
 #endif
     switch ( dm ) {
     case 0:     // INT
@@ -387,7 +387,7 @@ static void write_ipi (VCPU *vcpu, uint6
         memset (&c, 0, sizeof (c));
 
         if (arch_set_info_guest (targ, &c) != 0) {
-            printf ("arch_boot_vcpu: failure\n");
+            printk ("arch_boot_vcpu: failure\n");
             return;
         }
         /* First or next rendez-vous: set registers.  */
@@ -397,11 +397,11 @@ static void write_ipi (VCPU *vcpu, uint6
 
         if (test_and_clear_bit(_VCPUF_down,&targ->vcpu_flags)) {
             vcpu_wake(targ);
-            printf ("arch_boot_vcpu: vcpu %d awaken %016lx!\n",
+            printk ("arch_boot_vcpu: vcpu %d awaken %016lx!\n",
                     targ->vcpu_id, targ_regs->cr_iip);
         }
         else
-            printf ("arch_boot_vcpu: huu, already awaken!");
+            printk ("arch_boot_vcpu: huu, already awaken!");
     }
     else {
         int running = test_bit(_VCPUF_running,&targ->vcpu_flags);
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/vmx/vmx_vcpu.c
--- a/xen/arch/ia64/vmx/vmx_vcpu.c      Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/vmx/vmx_vcpu.c      Mon Oct 23 14:42:52 2006 +0100
@@ -246,7 +246,7 @@ check_entry(u64 va, u64 ps, char *str)
       va == 0x600000000000C000UL ) {
     stop();
      }
-     if (tlb_debug) printf("%s at %lx %lx\n", str, va, 1UL<<ps);
+     if (tlb_debug) printk("%s at %lx %lx\n", str, va, 1UL<<ps);
 }
 #endif
 
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/vmx/vmx_virt.c
--- a/xen/arch/ia64/vmx/vmx_virt.c      Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/vmx/vmx_virt.c      Mon Oct 23 14:42:52 2006 +0100
@@ -1364,7 +1364,7 @@ vmx_emulate(VCPU *vcpu, REGS *regs)
 #endif
 #if 0
 if ( (cause == 0xff && opcode == 0x1e000000000) || cause == 0 ) {
-               printf ("VMAL decode error: cause - %lx; op - %lx\n", 
+               printk ("VMAL decode error: cause - %lx; op - %lx\n", 
                        cause, opcode );
                return;
 }
@@ -1381,7 +1381,7 @@ if ( (cause == 0xff && opcode == 0x1e000
     else if (slot == 1)
         inst.inst = bundle.slot1a + (bundle.slot1b<<18);
     else if (slot == 2) inst.inst = bundle.slot2;
-    else printf("priv_handle_op: illegal slot: %d\n", slot);
+    else printk("priv_handle_op: illegal slot: %d\n", slot);
     slot_type = slot_types[bundle.template][slot];
     ia64_priv_decoder(slot_type, inst, &cause);
     if(cause==0){
@@ -1554,7 +1554,7 @@ if ( (cause == 0xff && opcode == 0x1e000
         status=vmx_emul_mov_from_cpuid(vcpu, inst);
         break;
     case EVENT_VMSW:
-        printf ("Unimplemented instruction %ld\n", cause);
+        printk ("Unimplemented instruction %ld\n", cause);
        status=IA64_FAULT;
         break;
     default:
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/dom0_ops.c
--- a/xen/arch/ia64/xen/dom0_ops.c      Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/dom0_ops.c      Mon Oct 23 14:42:52 2006 +0100
@@ -171,7 +171,7 @@ long arch_do_domctl(xen_domctl_t *op, XE
     }
     break;
     default:
-        printf("arch_do_domctl: unrecognized domctl: %d!!!\n",op->cmd);
+        printk("arch_do_domctl: unrecognized domctl: %d!!!\n",op->cmd);
         ret = -ENOSYS;
 
     }
@@ -211,7 +211,7 @@ long arch_do_sysctl(xen_sysctl_t *op, XE
     break;
 
     default:
-        printf("arch_do_sysctl: unrecognized sysctl: %d!!!\n",op->cmd);
+        printk("arch_do_sysctl: unrecognized sysctl: %d!!!\n",op->cmd);
         ret = -ENOSYS;
 
     }
@@ -273,7 +273,7 @@ do_dom0vp_op(unsigned long cmd,
         break;
     default:
         ret = -1;
-               printf("unknown dom0_vp_op 0x%lx\n", cmd);
+               printk("unknown dom0_vp_op 0x%lx\n", cmd);
         break;
     }
 
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/dom_fw.c
--- a/xen/arch/ia64/xen/dom_fw.c        Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/dom_fw.c        Mon Oct 23 14:42:52 2006 +0100
@@ -204,9 +204,9 @@ print_md(efi_memory_desc_t *md)
 
        size = md->num_pages << EFI_PAGE_SHIFT;
        if (size > ONE_MB)
-               printf ("(%luMB)\n", size >> 20);
+               printk ("(%luMB)\n", size >> 20);
        else
-               printf ("(%luKB)\n", size >> 10);
+               printk ("(%luKB)\n", size >> 10);
 }
 
 static u32 lsapic_nbr;
@@ -574,7 +574,7 @@ complete_dom0_memmap(struct domain *d,
 
                default:
                        /* Print a warning but continue.  */
-                       printf("complete_dom0_memmap: warning: "
+                       printk("complete_dom0_memmap: warning: "
                               "unhandled MDT entry type %u\n", md->type);
                }
        }
@@ -734,47 +734,47 @@ dom_fw_init(struct domain *d,
                /* Write messages to the console.  */
                touch_acpi_table();
 
-               printf("Domain0 EFI passthrough:");
+               printk("Domain0 EFI passthrough:");
                if (efi.mps) {
                        tables->efi_tables[i].guid = MPS_TABLE_GUID;
                        tables->efi_tables[i].table = __pa(efi.mps);
-                       printf(" MPS=0x%lx",tables->efi_tables[i].table);
+                       printk(" MPS=0x%lx",tables->efi_tables[i].table);
                        i++;
                }
 
                if (efi.acpi20) {
                        tables->efi_tables[i].guid = ACPI_20_TABLE_GUID;
                        tables->efi_tables[i].table = __pa(efi.acpi20);
-                       printf(" ACPI 2.0=0x%lx",tables->efi_tables[i].table);
+                       printk(" ACPI 2.0=0x%lx",tables->efi_tables[i].table);
                        i++;
                }
                if (efi.acpi) {
                        tables->efi_tables[i].guid = ACPI_TABLE_GUID;
                        tables->efi_tables[i].table = __pa(efi.acpi);
-                       printf(" ACPI=0x%lx",tables->efi_tables[i].table);
+                       printk(" ACPI=0x%lx",tables->efi_tables[i].table);
                        i++;
                }
                if (efi.smbios) {
                        tables->efi_tables[i].guid = SMBIOS_TABLE_GUID;
                        tables->efi_tables[i].table = __pa(efi.smbios);
-                       printf(" SMBIOS=0x%lx",tables->efi_tables[i].table);
+                       printk(" SMBIOS=0x%lx",tables->efi_tables[i].table);
                        i++;
                }
                if (efi.hcdp) {
                        tables->efi_tables[i].guid = HCDP_TABLE_GUID;
                        tables->efi_tables[i].table = __pa(efi.hcdp);
-                       printf(" HCDP=0x%lx",tables->efi_tables[i].table);
+                       printk(" HCDP=0x%lx",tables->efi_tables[i].table);
                        i++;
                }
-               printf("\n");
+               printk("\n");
        } else {
-               printf("DomainU EFI build up:");
+               printk("DomainU EFI build up:");
 
                tables->efi_tables[i].guid = ACPI_20_TABLE_GUID;
                tables->efi_tables[i].table = FW_ACPI_BASE_PADDR;
-               printf(" ACPI 2.0=0x%lx",tables->efi_tables[i].table);
+               printk(" ACPI 2.0=0x%lx",tables->efi_tables[i].table);
                i++;
-               printf("\n");
+               printk("\n");
        }
 
        /* fill in the SAL system table: */
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/domain.c
--- a/xen/arch/ia64/xen/domain.c        Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/domain.c        Mon Oct 23 14:42:52 2006 +0100
@@ -388,7 +388,7 @@ int arch_domain_create(struct domain *d)
        d->arch.ioport_caps = rangeset_new(d, "I/O Ports",
                                           RANGESETF_prettyprint_hex);
 
-       printf ("arch_domain_create: domain=%p\n", d);
+       printk ("arch_domain_create: domain=%p\n", d);
        return 0;
 
 fail_nomem:
@@ -598,7 +598,7 @@ domain_set_shared_info_va (unsigned long
 
        /* Note: this doesn't work well if other cpus are already running.
           However this is part of the spec :-)  */
-       printf ("Domain set shared_info_va to 0x%016lx\n", va);
+       printk ("Domain set shared_info_va to 0x%016lx\n", va);
        d->arch.shared_info_va = va;
 
        for_each_vcpu (d, v1) {
@@ -857,7 +857,7 @@ void alloc_dom0(void)
        }
        if (dom0_size % dom0_align) {
                dom0_size = (dom0_size / dom0_align + 1) * dom0_align;
-               printf("dom0_size rounded up to %ld, due to dom0_align=%lx\n",
+               printk("dom0_size rounded up to %ld, due to dom0_align=%lx\n",
                     dom0_size,dom0_align);
        }
 
@@ -915,7 +915,7 @@ int construct_dom0(struct domain *d,
        struct page_info *page = NULL;
 #endif
 
-//printf("construct_dom0: starting\n");
+//printk("construct_dom0: starting\n");
 
        /* Sanity! */
        BUG_ON(d != dom0);
@@ -1019,10 +1019,10 @@ int construct_dom0(struct domain *d,
        if (dom0_max_vcpus > MAX_VIRT_CPUS)
            dom0_max_vcpus = MAX_VIRT_CPUS;
        
-       printf ("Dom0 max_vcpus=%d\n", dom0_max_vcpus);
+       printk ("Dom0 max_vcpus=%d\n", dom0_max_vcpus);
        for ( i = 1; i < dom0_max_vcpus; i++ )
            if (alloc_vcpu(d, i, i) == NULL)
-               printf ("Cannot allocate dom0 vcpu %d\n", i);
+               printk ("Cannot allocate dom0 vcpu %d\n", i);
 
        /* Copy the OS image. */
        loaddomainelfimage(d,image_start);
@@ -1111,7 +1111,7 @@ void machine_restart(char * __unused)
 {
        console_start_sync();
        if (running_on_sim)
-               printf ("machine_restart called.  spinning...\n");
+               printk ("machine_restart called.  spinning...\n");
        else
                (*efi.reset_system)(EFI_RESET_WARM,0,0,NULL);
        while(1);
@@ -1123,7 +1123,7 @@ void machine_halt(void)
 {
        console_start_sync();
        if (running_on_sim)
-               printf ("machine_halt called.  spinning...\n");
+               printk ("machine_halt called.  spinning...\n");
        else
                cpu_halt();
        while(1);
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/faults.c
--- a/xen/arch/ia64/xen/faults.c        Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/faults.c        Mon Oct 23 14:42:52 2006 +0100
@@ -104,11 +104,11 @@ void reflect_extint(struct pt_regs *regs
        static int first_extint = 1;
 
        if (first_extint) {
-               printf("Delivering first extint to domain: isr=0x%lx, 
iip=0x%lx\n", isr, regs->cr_iip);
+               printk("Delivering first extint to domain: isr=0x%lx, 
iip=0x%lx\n", isr, regs->cr_iip);
                first_extint = 0;
        }
        if (vcpu_timer_pending_early(v))
-printf("*#*#*#* about to deliver early timer to domain 
%d!!!\n",v->domain->domain_id);
+printk("*#*#*#* about to deliver early timer to domain 
%d!!!\n",v->domain->domain_id);
        PSCB(current,itir) = 0;
        reflect_interruption(isr,regs,IA64_EXTINT_VECTOR);
 }
@@ -128,7 +128,7 @@ void reflect_event(struct pt_regs *regs)
                return;
 
        if (!PSCB(v,interrupt_collection_enabled))
-               printf("psr.ic off, delivering event, 
ipsr=%lx,iip=%lx,isr=%lx,viip=0x%lx\n",
+               printk("psr.ic off, delivering event, 
ipsr=%lx,iip=%lx,isr=%lx,viip=0x%lx\n",
                       regs->cr_ipsr, regs->cr_iip, isr, PSCB(v, iip));
        PSCB(v,unat) = regs->ar_unat;  // not sure if this is really needed?
        PSCB(v,precover_ifs) = regs->cr_ifs;
@@ -241,7 +241,7 @@ void ia64_do_page_fault (unsigned long a
 
        if (!PSCB(current,interrupt_collection_enabled)) {
                check_bad_nested_interruption(isr,regs,fault);
-               //printf("Delivering NESTED DATA TLB fault\n");
+               //printk("Delivering NESTED DATA TLB fault\n");
                fault = IA64_DATA_NESTED_TLB_VECTOR;
                regs->cr_iip = ((unsigned long) PSCBX(current,iva) + fault) & 
~0xffUL;
                regs->cr_ipsr = (regs->cr_ipsr & ~DELIVER_PSR_CLR) | 
DELIVER_PSR_SET;
@@ -370,7 +370,7 @@ ia64_fault (unsigned long vector, unsign
                "Unknown fault 13", "Unknown fault 14", "Unknown fault 15"
        };
 
-       printf("ia64_fault, vector=0x%lx, ifa=0x%016lx, iip=0x%016lx, 
ipsr=0x%016lx, isr=0x%016lx\n",
+       printk("ia64_fault, vector=0x%lx, ifa=0x%016lx, iip=0x%016lx, 
ipsr=0x%016lx, isr=0x%016lx\n",
               vector, ifa, regs->cr_iip, regs->cr_ipsr, isr);
 
 
@@ -380,7 +380,7 @@ ia64_fault (unsigned long vector, unsign
                 * the lfetch.
                 */
                ia64_psr(regs)->ed = 1;
-               printf("ia64_fault: handled lfetch.fault\n");
+               printk("ia64_fault: handled lfetch.fault\n");
                return;
        }
 
@@ -429,7 +429,7 @@ ia64_fault (unsigned long vector, unsign
                               regs->cr_iip + ia64_psr(regs)->ri,
                               regs->pr);
 # endif
-                       printf("ia64_fault: returning on hazard\n");
+                       printk("ia64_fault: returning on hazard\n");
                        return;
                }
                break;
@@ -588,7 +588,7 @@ ia64_handle_reflection (unsigned long if
                if (((isr >> 4L) & 0xfL) == 1) {
                        /* Fault is due to a register NaT consumption fault. */
                        //regs->eml_unat = 0;  FIXME: DO WE NEED THIS??
-                       printf("ia64_handle_reflection: handling regNaT 
fault\n");
+                       printk("ia64_handle_reflection: handling regNaT 
fault\n");
                        vector = IA64_NAT_CONSUMPTION_VECTOR; break;
                }
 #if 1
@@ -601,20 +601,20 @@ ia64_handle_reflection (unsigned long if
 #ifdef CONFIG_PRIVIFY
                /* Some privified operations are coded using reg+64 instead
                   of reg.  */
-               printf("*** NaT fault... attempting to handle as privop\n");
-               printf("isr=%016lx, ifa=%016lx, iip=%016lx, ipsr=%016lx\n",
+               printk("*** NaT fault... attempting to handle as privop\n");
+               printk("isr=%016lx, ifa=%016lx, iip=%016lx, ipsr=%016lx\n",
                       isr, ifa, regs->cr_iip, psr);
                //regs->eml_unat = 0;  FIXME: DO WE NEED THIS???
                // certain NaT faults are higher priority than privop faults
                vector = priv_emulate(v,regs,isr);
                if (vector == IA64_NO_FAULT) {
-                       printf("*** Handled privop masquerading as NaT 
fault\n");
+                       printk("*** Handled privop masquerading as NaT 
fault\n");
                        return;
                }
 #endif
                vector = IA64_NAT_CONSUMPTION_VECTOR; break;
            case 27:
-               //printf("*** Handled speculation vector, 
itc=%lx!\n",ia64_get_itc());
+               //printk("*** Handled speculation vector, 
itc=%lx!\n",ia64_get_itc());
                PSCB(current,iim) = iim;
                vector = IA64_SPECULATION_VECTOR; break;
            case 30:
@@ -629,7 +629,7 @@ ia64_handle_reflection (unsigned long if
                // fetch code fail
                if (IA64_RETRY == status)
                        return;
-               printf("ia64_handle_reflection: handling FP fault\n");
+               printk("ia64_handle_reflection: handling FP fault\n");
                vector = IA64_FP_FAULT_VECTOR; break;
            case 33:
                status = handle_fpu_swa(0, regs, isr);
@@ -638,20 +638,20 @@ ia64_handle_reflection (unsigned long if
                // fetch code fail
                if (IA64_RETRY == status)
                        return;
-               printf("ia64_handle_reflection: handling FP trap\n");
+               printk("ia64_handle_reflection: handling FP trap\n");
                vector = IA64_FP_TRAP_VECTOR; break;
            case 34:
-               printf("ia64_handle_reflection: handling lowerpriv trap\n");
+               printk("ia64_handle_reflection: handling lowerpriv trap\n");
                vector = IA64_LOWERPRIV_TRANSFER_TRAP_VECTOR; break;
            case 35:
-               printf("ia64_handle_reflection: handling taken branch trap\n");
+               printk("ia64_handle_reflection: handling taken branch trap\n");
                vector = IA64_TAKEN_BRANCH_TRAP_VECTOR; break;
            case 36:
-               printf("ia64_handle_reflection: handling single step trap\n");
+               printk("ia64_handle_reflection: handling single step trap\n");
                vector = IA64_SINGLE_STEP_TRAP_VECTOR; break;
 
            default:
-               printf("ia64_handle_reflection: unhandled 
vector=0x%lx\n",vector);
+               printk("ia64_handle_reflection: unhandled 
vector=0x%lx\n",vector);
                while(vector);
                return;
        }
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/fw_emul.c
--- a/xen/arch/ia64/xen/fw_emul.c       Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/fw_emul.c       Mon Oct 23 14:42:52 2006 +0100
@@ -73,20 +73,20 @@ sal_emulator (long index, unsigned long 
                        r9 = value;
                }
                else
-                    printf("NON-PRIV DOMAIN CALLED SAL_PCI_CONFIG_READ\n");
+                    printk("NON-PRIV DOMAIN CALLED SAL_PCI_CONFIG_READ\n");
                break;
            case SAL_PCI_CONFIG_WRITE:
                if (current->domain == dom0) {
                        if (((in1 & ~0xffffffffUL) && (in4 == 0)) ||
                            (in4 > 1) ||
                            (in2 > 8) || (in2 & (in2-1)))
-                               printf("*** 
SAL_PCI_CONF_WRITE?!?(adr=0x%lx,typ=0x%lx,sz=0x%lx,val=0x%lx)\n",
+                               printk("*** 
SAL_PCI_CONF_WRITE?!?(adr=0x%lx,typ=0x%lx,sz=0x%lx,val=0x%lx)\n",
                                        in1,in4,in2,in3);
                        // note that args are in a different order!!
                        status = ia64_sal_pci_config_write(in1,in4,in2,in3);
                }
                else
-                    printf("NON-PRIV DOMAIN CALLED SAL_PCI_CONFIG_WRITE\n");
+                    printk("NON-PRIV DOMAIN CALLED SAL_PCI_CONFIG_WRITE\n");
                break;
            case SAL_SET_VECTORS:
                if (in1 == SAL_VECTOR_OS_BOOT_RENDEZ) {
@@ -102,7 +102,7 @@ sal_emulator (long index, unsigned long 
                        }
                }
                else
-                       printf("*** CALLED SAL_SET_VECTORS %lu.  IGNORED...\n",
+                       printk("*** CALLED SAL_SET_VECTORS %lu.  IGNORED...\n",
                               in1);
                break;
            case SAL_GET_STATE_INFO:
@@ -119,10 +119,10 @@ sal_emulator (long index, unsigned long 
                /* Noop.  */
                break;
            case SAL_MC_RENDEZ:
-               printf("*** CALLED SAL_MC_RENDEZ.  IGNORED...\n");
+               printk("*** CALLED SAL_MC_RENDEZ.  IGNORED...\n");
                break;
            case SAL_MC_SET_PARAMS:
-               printf("*** CALLED SAL_MC_SET_PARAMS.  IGNORED...\n");
+               printk("*** CALLED SAL_MC_SET_PARAMS.  IGNORED...\n");
                break;
            case SAL_CACHE_FLUSH:
                if (1) {
@@ -139,13 +139,13 @@ sal_emulator (long index, unsigned long 
                }
                break;
            case SAL_CACHE_INIT:
-               printf("*** CALLED SAL_CACHE_INIT.  IGNORED...\n");
+               printk("*** CALLED SAL_CACHE_INIT.  IGNORED...\n");
                break;
            case SAL_UPDATE_PAL:
-               printf("*** CALLED SAL_UPDATE_PAL.  IGNORED...\n");
+               printk("*** CALLED SAL_UPDATE_PAL.  IGNORED...\n");
                break;
            default:
-               printf("*** CALLED SAL_ WITH UNKNOWN INDEX.  IGNORED...\n");
+               printk("*** CALLED SAL_ WITH UNKNOWN INDEX.  IGNORED...\n");
                status = -1;
                break;
        }
@@ -344,7 +344,7 @@ xen_pal_emulator(unsigned long index, u6
                break;
            case PAL_HALT:
                    if (current->domain == dom0) {
-                           printf ("Domain0 halts the machine\n");
+                           printk ("Domain0 halts the machine\n");
                            console_start_sync();
                            (*efi.reset_system)(EFI_RESET_SHUTDOWN,0,0,NULL);
                    }
@@ -400,7 +400,7 @@ efi_emulate_get_time(
        struct page_info *tc_page = NULL;
        efi_status_t status = 0;
 
-       //printf("efi_get_time(%016lx,%016lx) called\n", tv_addr, tc_addr);
+       //printk("efi_get_time(%016lx,%016lx) called\n", tv_addr, tc_addr);
        tv = efi_translate_domain_addr(tv_addr, fault, &tv_page);
        if (*fault != IA64_NO_FAULT)
                goto errout;
@@ -410,9 +410,9 @@ efi_emulate_get_time(
                        goto errout;
        }
 
-       //printf("efi_get_time(%016lx,%016lx) translated to xen virtual 
address\n", tv, tc);
+       //printk("efi_get_time(%016lx,%016lx) translated to xen virtual 
address\n", tv, tc);
        status = (*efi.get_time)((efi_time_t *) tv, (efi_time_cap_t *) tc);
-       //printf("efi_get_time returns %lx\n", status);
+       //printk("efi_get_time returns %lx\n", status);
 
 errout:
        if (tc_page != NULL)
@@ -666,14 +666,14 @@ efi_emulate_set_virtual_address_map(
        fpswa_interface_t *fpswa_inf = d->arch.fpswa_inf;
 
        if (descriptor_version != EFI_MEMDESC_VERSION) {
-               printf ("efi_emulate_set_virtual_address_map: memory "
+               printk ("efi_emulate_set_virtual_address_map: memory "
                        "descriptor version unmatched (%d vs %d)\n",
                        (int)descriptor_version, EFI_MEMDESC_VERSION);
                return EFI_INVALID_PARAMETER;
        }
 
        if (descriptor_size != sizeof(efi_memory_desc_t)) {
-               printf ("efi_emulate_set_virtual_address_map: memory descriptor 
size unmatched\n");
+               printk ("efi_emulate_set_virtual_address_map: memory descriptor 
size unmatched\n");
                return EFI_INVALID_PARAMETER;
        }
 
@@ -686,7 +686,7 @@ efi_emulate_set_virtual_address_map(
 
        for (p = efi_map_start; p < efi_map_end; p += efi_desc_size) {
                if (copy_from_user(&entry, p, sizeof(efi_memory_desc_t))) {
-                       printf ("efi_emulate_set_virtual_address_map: 
copy_from_user() fault. addr=0x%p\n", p);
+                       printk ("efi_emulate_set_virtual_address_map: 
copy_from_user() fault. addr=0x%p\n", p);
                        return EFI_UNSUPPORTED;
                }
 
@@ -814,7 +814,7 @@ efi_emulator (struct pt_regs *regs, IA64
                status = EFI_UNSUPPORTED;
                break;
            default:
-               printf("unknown ia64 fw hypercall %lx\n", regs->r2);
+               printk("unknown ia64 fw hypercall %lx\n", regs->r2);
                status = EFI_UNSUPPORTED;
        }
 
@@ -835,7 +835,7 @@ do_ssc(unsigned long ssc, struct pt_regs
            case SSC_PUTCHAR:
                buf[0] = arg0;
                buf[1] = '\0';
-               printf(buf);
+               printk(buf);
                break;
            case SSC_GETCHAR:
                retval = ia64_ssc(0,0,0,0,ssc);
@@ -848,7 +848,7 @@ do_ssc(unsigned long ssc, struct pt_regs
 /**/                   stat = (struct ssc_disk_stat *)__va(arg0);
 ///**/                 if (stat->fd == last_fd) stat->count = last_count;
 /**/                   stat->count = last_count;
-//if (last_count >= PAGE_SIZE) printf("ssc_wait: 
stat->fd=%d,last_fd=%d,last_count=%d\n",stat->fd,last_fd,last_count);
+//if (last_count >= PAGE_SIZE) printk("ssc_wait: 
stat->fd=%d,last_fd=%d,last_count=%d\n",stat->fd,last_fd,last_count);
 ///**/                 retval = ia64_ssc(arg0,0,0,0,ssc);
 /**/                   retval = 0;
                }
@@ -857,7 +857,7 @@ do_ssc(unsigned long ssc, struct pt_regs
                break;
            case SSC_OPEN:
                arg1 = vcpu_get_gr(current,33); // access rights
-if (!running_on_sim) { printf("SSC_OPEN, not implemented on hardware.  
(ignoring...)\n"); arg0 = 0; }
+if (!running_on_sim) { printk("SSC_OPEN, not implemented on hardware.  
(ignoring...)\n"); arg0 = 0; }
                if (arg0) {     // metaphysical address
                        arg0 = translate_domain_mpaddr(arg0, NULL);
                        retval = ia64_ssc(arg0,arg1,0,0,ssc);
@@ -867,7 +867,7 @@ if (!running_on_sim) { printf("SSC_OPEN,
                break;
            case SSC_WRITE:
            case SSC_READ:
-//if (ssc == SSC_WRITE) printf("DOING AN SSC_WRITE\n");
+//if (ssc == SSC_WRITE) printk("DOING AN SSC_WRITE\n");
                arg1 = vcpu_get_gr(current,33);
                arg2 = vcpu_get_gr(current,34);
                arg3 = vcpu_get_gr(current,35);
@@ -883,7 +883,7 @@ if (!running_on_sim) { printf("SSC_OPEN,
 /**/                   last_fd = arg1;
 /**/                   last_count = len;
                        mpaddr = req->addr;
-//if (last_count >= PAGE_SIZE) printf("do_ssc: read fd=%d, addr=%p, len=%lx 
",last_fd,mpaddr,len);
+//if (last_count >= PAGE_SIZE) printk("do_ssc: read fd=%d, addr=%p, len=%lx 
",last_fd,mpaddr,len);
                        retval = 0;
                        if ((mpaddr & PAGE_MASK) != ((mpaddr+len-1) & 
PAGE_MASK)) {
                                // do partial page first
@@ -894,7 +894,7 @@ if (!running_on_sim) { printf("SSC_OPEN,
                                arg3 += req->len; // file offset
 /**/                           last_stat.fd = last_fd;
 /**/                           
(void)ia64_ssc(__pa(&last_stat),0,0,0,SSC_WAIT_COMPLETION);
-//if (last_count >= PAGE_SIZE) printf("ssc(%p,%lx)[part]=%x 
",req->addr,req->len,retval);
+//if (last_count >= PAGE_SIZE) printk("ssc(%p,%lx)[part]=%x 
",req->addr,req->len,retval);
                        }
                        if (retval >= 0) while (len > 0) {
                                req->addr = translate_domain_mpaddr(mpaddr, 
NULL);
@@ -905,27 +905,27 @@ if (!running_on_sim) { printf("SSC_OPEN,
 // TEMP REMOVED AGAIN                          arg3 += req->len; // file offset
 /**/                           last_stat.fd = last_fd;
 /**/                           
(void)ia64_ssc(__pa(&last_stat),0,0,0,SSC_WAIT_COMPLETION);
-//if (last_count >= PAGE_SIZE) printf("ssc(%p,%lx)=%x 
",req->addr,req->len,retval);
+//if (last_count >= PAGE_SIZE) printk("ssc(%p,%lx)=%x 
",req->addr,req->len,retval);
                        }
                        // set it back to the original value
                        req->len = last_count;
                }
                else retval = -1L;
                vcpu_set_gr(current,8,retval,0);
-//if (last_count >= PAGE_SIZE) printf("retval=%x\n",retval);
+//if (last_count >= PAGE_SIZE) printk("retval=%x\n",retval);
                break;
            case SSC_CONNECT_INTERRUPT:
                arg1 = vcpu_get_gr(current,33);
                arg2 = vcpu_get_gr(current,34);
                arg3 = vcpu_get_gr(current,35);
-               if (!running_on_sim) { printf("SSC_CONNECT_INTERRUPT, not 
implemented on hardware.  (ignoring...)\n"); break; }
+               if (!running_on_sim) { printk("SSC_CONNECT_INTERRUPT, not 
implemented on hardware.  (ignoring...)\n"); break; }
                (void)ia64_ssc(arg0,arg1,arg2,arg3,ssc);
                break;
            case SSC_NETDEV_PROBE:
                vcpu_set_gr(current,8,-1L,0);
                break;
            default:
-               printf("ia64_handle_break: bad ssc code %lx, iip=0x%lx, 
b0=0x%lx... spinning\n",
+               printk("ia64_handle_break: bad ssc code %lx, iip=0x%lx, 
b0=0x%lx... spinning\n",
                        ssc, regs->cr_iip, regs->b0);
                while(1);
                break;
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/hypercall.c
--- a/xen/arch/ia64/xen/hypercall.c     Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/hypercall.c     Mon Oct 23 14:42:52 2006 +0100
@@ -163,7 +163,7 @@ fw_hypercall_ipi (struct pt_regs *regs)
                        memset (&c, 0, sizeof (c));
 
                        if (arch_set_info_guest (targ, &c) != 0) {
-                               printf ("arch_boot_vcpu: failure\n");
+                               printk ("arch_boot_vcpu: failure\n");
                                return;
                        }
                }
@@ -177,11 +177,11 @@ fw_hypercall_ipi (struct pt_regs *regs)
                if (test_and_clear_bit(_VCPUF_down,
                                       &targ->vcpu_flags)) {
                        vcpu_wake(targ);
-                       printf ("arch_boot_vcpu: vcpu %d awaken\n",
+                       printk ("arch_boot_vcpu: vcpu %d awaken\n",
                                targ->vcpu_id);
                }
                else
-                       printf ("arch_boot_vcpu: huu, already awaken!\n");
+                       printk ("arch_boot_vcpu: huu, already awaken!\n");
        }
        else {
                int running = test_bit(_VCPUF_running,
@@ -214,7 +214,7 @@ fw_hypercall (struct pt_regs *regs)
        perfc_incra(fw_hypercall, index >> 8);
        switch (index) {
            case FW_HYPERCALL_PAL_CALL:
-               //printf("*** PAL hypercall: index=%d\n",regs->r28);
+               //printk("*** PAL hypercall: index=%d\n",regs->r28);
                //FIXME: This should call a C routine
 #if 0
                // This is very conservative, but avoids a possible
@@ -229,7 +229,7 @@ fw_hypercall (struct pt_regs *regs)
                                event_pending(v)) {
                                perfc_incrc(idle_when_pending);
                                vcpu_pend_unspecified_interrupt(v);
-//printf("idle w/int#%d pending!\n",pi);
+//printk("idle w/int#%d pending!\n",pi);
 //this shouldn't happen, but it apparently does quite a bit!  so don't
 //allow it to happen... i.e. if a domain has an interrupt pending and
 //it tries to halt itself because it thinks it is idle, just return here
@@ -295,7 +295,7 @@ fw_hypercall (struct pt_regs *regs)
                regs->r11 = fpswa_ret.err2;
                break;
            default:
-               printf("unknown ia64 fw hypercall %lx\n", regs->r2);
+               printk("unknown ia64 fw hypercall %lx\n", regs->r2);
                regs->r8 = do_ni_hypercall();
        }
        return IA64_NO_FAULT;
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/hyperprivop.S
--- a/xen/arch/ia64/xen/hyperprivop.S   Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/hyperprivop.S   Mon Oct 23 14:42:52 2006 +0100
@@ -203,7 +203,7 @@ END(fast_hyperprivop)
 
 // give up for now if: ipsr.be==1, ipsr.pp==1
 // from reflect_interruption, don't need to:
-//  - printf first extint (debug only)
+//  - printk first extint (debug only)
 //  - check for interrupt collection enabled (routine will force on)
 //  - set ifa (not valid for extint)
 //  - set iha (not valid for extint)
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/irq.c
--- a/xen/arch/ia64/xen/irq.c   Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/irq.c   Mon Oct 23 14:42:52 2006 +0100
@@ -481,7 +481,7 @@ xen_debug_irq(unsigned long vector, stru
                firstirq = 0;
        }
        if (firsttime[vector]) {
-               printf("**** (entry) First received int on 
vector=%lu,itc=%lx\n",
+               printk("**** (entry) First received int on 
vector=%lu,itc=%lx\n",
                        (unsigned long) vector, ia64_get_itc());
                firsttime[vector] = 0;
        }
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/mm.c
--- a/xen/arch/ia64/xen/mm.c    Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/mm.c    Mon Oct 23 14:42:52 2006 +0100
@@ -460,7 +460,7 @@ u64 translate_domain_pte(u64 pteval, u64
                           This can happen when domU tries to touch i/o
                           port space.  Also prevents possible address
                           aliasing issues.  */
-                       printf("Warning: UC to WB for mpaddr=%lx\n", mpaddr);
+                       printk("Warning: UC to WB for mpaddr=%lx\n", mpaddr);
                        pteval = (pteval & ~_PAGE_MA_MASK) | _PAGE_MA_WB;
                }
                break;
@@ -715,7 +715,7 @@ __assign_new_domain_page(struct domain *
 
     p = alloc_domheap_page(d);
     if (unlikely(!p)) {
-        printf("assign_new_domain_page: Can't alloc!!!! Aaaargh!\n");
+        printk("assign_new_domain_page: Can't alloc!!!! Aaaargh!\n");
         return(p);
     }
 
@@ -726,7 +726,7 @@ __assign_new_domain_page(struct domain *
                  && maddr < __get_cpu_var(vhpt_pend))) {
         /* FIXME: how can this happen ?
            vhpt is allocated by alloc_domheap_page.  */
-        printf("assign_new_domain_page: reassigned vhpt page %lx!!\n",
+        printk("assign_new_domain_page: reassigned vhpt page %lx!!\n",
                maddr);
     }
 
@@ -1536,7 +1536,7 @@ void domain_cache_flush (struct domain *
             }
         }
     }
-    //printf ("domain_cache_flush: %d %d pages\n", d->domain_id, nbr_page);
+    //printk ("domain_cache_flush: %d %d pages\n", d->domain_id, nbr_page);
 }
 
 #ifdef VERBOSE
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/privop.c
--- a/xen/arch/ia64/xen/privop.c        Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/privop.c        Mon Oct 23 14:42:52 2006 +0100
@@ -525,14 +525,14 @@ priv_handle_op(VCPU *vcpu, REGS *regs, i
        if (iip==0xa000000100001820) {
                static int firstpagefault = 1;
                if (firstpagefault) {
-                       printf("*** First time to domain page fault!\n");       
                        firstpagefault=0;
+                       printk("*** First time to domain page fault!\n");       
                        firstpagefault=0;
                }
        }
 #endif
        if (privop_trace) {
                static long i = 400;
-               //if (i > 0) printf("priv_handle_op: at 0x%lx\n",iip);
-               if (i > 0) printf("priv_handle_op: privop trace at 0x%lx, 
itc=%lx, itm=%lx\n",
+               //if (i > 0) printk("priv_handle_op: at 0x%lx\n",iip);
+               if (i > 0) printk("priv_handle_op: privop trace at 0x%lx, 
itc=%lx, itm=%lx\n",
                        iip,ia64_get_itc(),ia64_get_itm());
                i--;
        }
@@ -541,11 +541,11 @@ priv_handle_op(VCPU *vcpu, REGS *regs, i
        else if (slot == 1)
                inst.inst = ((bundle.i64[0]>>46) | bundle.i64[1]<<18) & MASK_41;
        else if (slot == 2) inst.inst = (bundle.i64[1]>>23) & MASK_41; 
-       else printf("priv_handle_op: illegal slot: %d\n", slot);
+       else printk("priv_handle_op: illegal slot: %d\n", slot);
 
        slot_type = slot_types[bundle.template][slot];
        if (priv_verbose) {
-               printf("priv_handle_op: checking bundle at 0x%lx (op=0x%016lx) 
slot %d (type=%d)\n",
+               printk("priv_handle_op: checking bundle at 0x%lx (op=0x%016lx) 
slot %d (type=%d)\n",
                 iip, (UINT64)inst.inst, slot, slot_type);
        }
        if (slot_type == B && inst.generic.major == 0 && inst.B8.x6 == 0x0) {
@@ -648,10 +648,10 @@ priv_handle_op(VCPU *vcpu, REGS *regs, i
            default:
                break;
        }
-        //printf("We who are about do die salute you\n");
-       printf("priv_handle_op: can't handle privop at 0x%lx (op=0x%016lx) slot 
%d (type=%d), ipsr=0x%lx\n",
+        //printk("We who are about do die salute you\n");
+       printk("priv_handle_op: can't handle privop at 0x%lx (op=0x%016lx) slot 
%d (type=%d), ipsr=0x%lx\n",
                 iip, (UINT64)inst.inst, slot, slot_type, ipsr);
-        //printf("vtop(0x%lx)==0x%lx\n", iip, tr_vtop(iip));
+        //printk("vtop(0x%lx)==0x%lx\n", iip, tr_vtop(iip));
         //thread_mozambique("privop fault\n");
        return (IA64_ILLOP_FAULT);
 }
@@ -676,8 +676,8 @@ priv_emulate(VCPU *vcpu, REGS *regs, UIN
 
        // handle privops masked as illops? and breaks (6)
        if (isrcode != 1 && isrcode != 2 && isrcode != 0 && isrcode != 6) {
-               printf("priv_emulate: isrcode != 0 or 1 or 2\n");
-               printf("priv_emulate: returning ILLOP, not implemented!\n");
+               printk("priv_emulate: isrcode != 0 or 1 or 2\n");
+               printk("priv_emulate: returning ILLOP, not implemented!\n");
                while (1);
                return IA64_ILLOP_FAULT;
        }
@@ -690,7 +690,7 @@ priv_emulate(VCPU *vcpu, REGS *regs, UIN
                (void)vcpu_increment_iip(vcpu);
        }
        if (fault == IA64_ILLOP_FAULT)
-               printf("priv_emulate: priv_handle_op fails, "
+               printk("priv_emulate: priv_handle_op fails, "
                       "isr=0x%lx iip=%lx\n",isr, regs->cr_iip);
        return fault;
 }
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/regionreg.c
--- a/xen/arch/ia64/xen/regionreg.c     Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/regionreg.c     Mon Oct 23 14:42:52 2006 +0100
@@ -106,7 +106,7 @@ void init_rid_allocator (void)
        /* Due to RID mangling, we expect 24 RID bits!
           This test should be removed if RID mangling is removed/modified.  */
        if (implemented_rid_bits != 24) {
-               printf ("RID mangling expected 24 RID bits, got only %d!\n",
+               printk ("RID mangling expected 24 RID bits, got only %d!\n",
                        implemented_rid_bits);
                BUG();
        }
@@ -117,14 +117,14 @@ void init_rid_allocator (void)
 
        /* Check for too small values.  */
        if (domain_rid_bits_default < IA64_MIN_IMPL_RID_BITS) {
-               printf ("Default domain rid bits %d is too small, use %d\n",
+               printk ("Default domain rid bits %d is too small, use %d\n",
                        domain_rid_bits_default, IA64_MIN_IMPL_RID_BITS);
                domain_rid_bits_default = IA64_MIN_IMPL_RID_BITS;
        }
 
        log_blocks = (implemented_rid_bits - IA64_MIN_IMPL_RID_BITS);
 
-       printf ("Maximum number of domains: %d; %d RID bits per domain\n",
+       printk ("Maximum number of domains: %d; %d RID bits per domain\n",
                (1 << (implemented_rid_bits - domain_rid_bits_default)) - 1,
                domain_rid_bits_default);
        
@@ -185,7 +185,7 @@ int allocate_rid_range(struct domain *d,
        d->arch.metaphysical_rr0 = allocate_metaphysical_rr(d, 0);
        d->arch.metaphysical_rr4 = allocate_metaphysical_rr(d, 1);
 
-       printf("### domain %p: rid=%x-%x mp_rid=%x\n",
+       printk("### domain %p: rid=%x-%x mp_rid=%x\n",
               d, d->arch.starting_rid, d->arch.ending_rid,
               d->arch.starting_mp_rid);
        
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/vcpu.c
--- a/xen/arch/ia64/xen/vcpu.c  Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/vcpu.c  Mon Oct 23 14:42:52 2006 +0100
@@ -189,7 +189,7 @@ IA64FAULT vcpu_set_ar(VCPU *vcpu, UINT64
        if (reg == 44) return (vcpu_set_itc(vcpu,val));
        else if (reg == 27) return (IA64_ILLOP_FAULT);
        else if (reg == 24)
-           printf("warning: setting ar.eflg is a no-op; no IA-32 support\n");
+           printk("warning: setting ar.eflg is a no-op; no IA-32 support\n");
        else if (reg > 7) return (IA64_ILLOP_FAULT);
        else {
                PSCB(vcpu,krs[reg]) = val;
@@ -201,7 +201,7 @@ IA64FAULT vcpu_get_ar(VCPU *vcpu, UINT64
 IA64FAULT vcpu_get_ar(VCPU *vcpu, UINT64 reg, UINT64 *val)
 {
        if (reg == 24)
-           printf("warning: getting ar.eflg is a no-op; no IA-32 support\n");
+           printk("warning: getting ar.eflg is a no-op; no IA-32 support\n");
        else if (reg > 7) return (IA64_ILLOP_FAULT);
        else *val = PSCB(vcpu,krs[reg]);
        return IA64_NO_FAULT;
@@ -304,7 +304,7 @@ IA64FAULT vcpu_set_psr_sm(VCPU *vcpu, UI
        if (imm.sp) { ipsr->sp = 1; psr.sp = 1; }
        if (imm.i) {
                if (vcpu->vcpu_info->evtchn_upcall_mask) {
-//printf("vcpu_set_psr_sm: psr.ic 0->1\n");
+//printk("vcpu_set_psr_sm: psr.ic 0->1\n");
                        enabling_interrupts = 1;
                }
                vcpu->vcpu_info->evtchn_upcall_mask = 0;
@@ -316,7 +316,7 @@ IA64FAULT vcpu_set_psr_sm(VCPU *vcpu, UI
        if (imm.ac) { ipsr->ac = 1; psr.ac = 1; }
        if (imm.up) { ipsr->up = 1; psr.up = 1; }
        if (imm.be) {
-               printf("*** DOMAIN TRYING TO TURN ON BIG-ENDIAN!!!\n");
+               printk("*** DOMAIN TRYING TO TURN ON BIG-ENDIAN!!!\n");
                return (IA64_ILLOP_FAULT);
        }
        if (imm.dt) vcpu_set_metaphysical_mode(vcpu,FALSE);
@@ -365,7 +365,7 @@ IA64FAULT vcpu_set_psr_l(VCPU *vcpu, UIN
        if (newpsr.dt && newpsr.rt) vcpu_set_metaphysical_mode(vcpu,FALSE);
        else vcpu_set_metaphysical_mode(vcpu,TRUE);
        if (newpsr.be) {
-               printf("*** DOMAIN TRYING TO TURN ON BIG-ENDIAN!!!\n");
+               printk("*** DOMAIN TRYING TO TURN ON BIG-ENDIAN!!!\n");
                return (IA64_ILLOP_FAULT);
        }
        if (enabling_interrupts &&
@@ -408,7 +408,7 @@ UINT64 vcpu_get_ipsr_int_state(VCPU *vcp
        UINT64 dcr = PSCBX(vcpu,dcr);
        PSR psr;
 
-       //printf("*** vcpu_get_ipsr_int_state (0x%016lx)...\n",prevpsr);
+       //printk("*** vcpu_get_ipsr_int_state (0x%016lx)...\n",prevpsr);
        psr.i64 = prevpsr;
        psr.ia64_psr.be = 0; if (dcr & IA64_DCR_BE) psr.ia64_psr.be = 1;
        psr.ia64_psr.pp = 0; if (dcr & IA64_DCR_PP) psr.ia64_psr.pp = 1;
@@ -418,7 +418,7 @@ UINT64 vcpu_get_ipsr_int_state(VCPU *vcp
        psr.ia64_psr.dt = 1; psr.ia64_psr.it = 1; psr.ia64_psr.rt = 1;
        if (psr.ia64_psr.cpl == 2) psr.ia64_psr.cpl = 0; // !!!! fool domain
        // psr.pk = 1;
-       //printf("returns 0x%016lx...\n",psr.i64);
+       //printk("returns 0x%016lx...\n",psr.i64);
        return psr.i64;
 }
 
@@ -519,7 +519,7 @@ IA64FAULT vcpu_get_iipa(VCPU *vcpu, UINT
        UINT64 val = PSCB(vcpu,iipa);
        // SP entry code does not save iipa yet nor does it get
        //  properly delivered in the pscb
-//     printf("*** vcpu_get_iipa: cr.iipa not fully implemented yet!!\n");
+//     printk("*** vcpu_get_iipa: cr.iipa not fully implemented yet!!\n");
        *pval = val;
        return (IA64_NO_FAULT);
 }
@@ -570,7 +570,7 @@ IA64FAULT vcpu_set_pta(VCPU *vcpu, UINT6
 IA64FAULT vcpu_set_pta(VCPU *vcpu, UINT64 val)
 {
        if (val & IA64_PTA_LFMT) {
-               printf("*** No support for VHPT long format yet!!\n");
+               printk("*** No support for VHPT long format yet!!\n");
                return (IA64_ILLOP_FAULT);
        }
        if (val & (0x3f<<9)) /* reserved fields */ return IA64_RSVDREG_FAULT;
@@ -622,7 +622,7 @@ IA64FAULT vcpu_set_iipa(VCPU *vcpu, UINT
 {
        // SP entry code does not save iipa yet nor does it get
        //  properly delivered in the pscb
-//     printf("*** vcpu_set_iipa: cr.iipa not fully implemented yet!!\n");
+//     printk("*** vcpu_set_iipa: cr.iipa not fully implemented yet!!\n");
        PSCB(vcpu,iipa) = val;
        return IA64_NO_FAULT;
 }
@@ -658,12 +658,12 @@ void vcpu_pend_interrupt(VCPU *vcpu, UIN
 void vcpu_pend_interrupt(VCPU *vcpu, UINT64 vector)
 {
        if (vector & ~0xff) {
-               printf("vcpu_pend_interrupt: bad vector\n");
+               printk("vcpu_pend_interrupt: bad vector\n");
                return;
        }
 
        if (vcpu->arch.event_callback_ip) {
-               printf("Deprecated interface. Move to new event based 
solution\n");
+               printk("Deprecated interface. Move to new event based 
solution\n");
                return;
        }
                
@@ -718,7 +718,7 @@ check_start:
        }
        // have a pending,deliverable interrupt... see if it is masked
        bitnum = ia64_fls(bits);
-//printf("XXXXXXX vcpu_check_pending_interrupts: got bitnum=%p...\n",bitnum);
+//printk("XXXXXXX vcpu_check_pending_interrupts: got bitnum=%p...\n",bitnum);
        vector = bitnum+(i*64);
        mask = 1L << bitnum;
        /* sanity check for guest timer interrupt */
@@ -730,24 +730,24 @@ check_start:
                        goto check_start;
                }
        }
-//printf("XXXXXXX vcpu_check_pending_interrupts: got vector=%p...\n",vector);
+//printk("XXXXXXX vcpu_check_pending_interrupts: got vector=%p...\n",vector);
        if (*r >= mask) {
                // masked by equal inservice
-//printf("but masked by equal inservice\n");
+//printk("but masked by equal inservice\n");
                return SPURIOUS_VECTOR;
        }
        if (PSCB(vcpu,tpr) & IA64_TPR_MMI) {
                // tpr.mmi is set
-//printf("but masked by tpr.mmi\n");
+//printk("but masked by tpr.mmi\n");
                return SPURIOUS_VECTOR;
        }
        if (((PSCB(vcpu,tpr) & IA64_TPR_MIC) + 15) >= vector) {
                //tpr.mic masks class
-//printf("but masked by tpr.mic\n");
+//printk("but masked by tpr.mic\n");
                return SPURIOUS_VECTOR;
        }
 
-//printf("returned to caller\n");
+//printk("returned to caller\n");
        return vector;
 }
 
@@ -805,7 +805,7 @@ IA64FAULT vcpu_get_ivr(VCPU *vcpu, UINT6
 #if 0
        if (vector == (PSCB(vcpu,itv) & 0xff)) {
            if (!(++count[domid] & ((HEARTBEAT_FREQ*1024)-1))) {
-               printf("Dom%d heartbeat... ticks=%lx,nonticks=%lx\n",
+               printk("Dom%d heartbeat... ticks=%lx,nonticks=%lx\n",
                        domid, count[domid], nonclockcount[domid]);
                //count[domid] = 0;
                //dump_runq();
@@ -818,7 +818,7 @@ IA64FAULT vcpu_get_ivr(VCPU *vcpu, UINT6
        // getting ivr has "side effects"
 #ifdef IRQ_DEBUG
        if (firsttime[vector]) {
-               printf("*** First get_ivr on vector=%lu,itc=%lx\n",
+               printk("*** First get_ivr on vector=%lu,itc=%lx\n",
                        vector,ia64_get_itc());
                firsttime[vector]=0;
        }
@@ -832,7 +832,7 @@ IA64FAULT vcpu_get_ivr(VCPU *vcpu, UINT6
 
        i = vector >> 6;
        mask = 1L << (vector & 0x3f);
-//printf("ZZZZZZ vcpu_get_ivr: setting insvc mask for vector %lu\n",vector);
+//printk("ZZZZZZ vcpu_get_ivr: setting insvc mask for vector %lu\n",vector);
        PSCBX(vcpu,insvc[i]) |= mask;
        PSCBX(vcpu,irr[i]) &= ~mask;
        //PSCB(vcpu,pending_interruption)--;
@@ -897,7 +897,7 @@ IA64FAULT vcpu_get_lrr0(VCPU *vcpu, UINT
 IA64FAULT vcpu_get_lrr0(VCPU *vcpu, UINT64 *pval)
 {
        // fix this when setting values other than m-bit is supported
-       printf("vcpu_get_lrr0: Unmasked interrupts unsupported\n");
+       printk("vcpu_get_lrr0: Unmasked interrupts unsupported\n");
        *pval = (1L << 16);
        return (IA64_NO_FAULT);
 }
@@ -905,14 +905,14 @@ IA64FAULT vcpu_get_lrr1(VCPU *vcpu, UINT
 IA64FAULT vcpu_get_lrr1(VCPU *vcpu, UINT64 *pval)
 {
        // fix this when setting values other than m-bit is supported
-       printf("vcpu_get_lrr1: Unmasked interrupts unsupported\n");
+       printk("vcpu_get_lrr1: Unmasked interrupts unsupported\n");
        *pval = (1L << 16);
        return (IA64_NO_FAULT);
 }
 
 IA64FAULT vcpu_set_lid(VCPU *vcpu, UINT64 val)
 {
-       printf("vcpu_set_lid: Setting cr.lid is unsupported\n");
+       printk("vcpu_set_lid: Setting cr.lid is unsupported\n");
        return (IA64_ILLOP_FAULT);
 }
 
@@ -934,7 +934,7 @@ IA64FAULT vcpu_set_eoi(VCPU *vcpu, UINT6
        p = &PSCBX(vcpu,insvc[3]);
        for (i = 3; (i >= 0) && !(bits = *p); i--, p--);
        if (i < 0) {
-               printf("Trying to EOI interrupt when none are in-service.\n");
+               printk("Trying to EOI interrupt when none are in-service.\n");
                return IA64_NO_FAULT;
        }
        bitnum = ia64_fls(bits);
@@ -946,18 +946,18 @@ IA64FAULT vcpu_set_eoi(VCPU *vcpu, UINT6
        if (!vcpu->vcpu_info->evtchn_upcall_mask) { // but only if enabled...
                // worry about this later... Linux only calls eoi
                // with interrupts disabled
-               printf("Trying to EOI interrupt with interrupts enabled\n");
+               printk("Trying to EOI interrupt with interrupts enabled\n");
        }
        if (vcpu_check_pending_interrupts(vcpu) != SPURIOUS_VECTOR)
                PSCB(vcpu,pending_interruption) = 1;
-//printf("YYYYY vcpu_set_eoi: Successful\n");
+//printk("YYYYY vcpu_set_eoi: Successful\n");
        return (IA64_NO_FAULT);
 }
 
 IA64FAULT vcpu_set_lrr0(VCPU *vcpu, UINT64 val)
 {
        if (!(val & (1L << 16))) {
-               printf("vcpu_set_lrr0: Unmasked interrupts unsupported\n");
+               printk("vcpu_set_lrr0: Unmasked interrupts unsupported\n");
                return (IA64_ILLOP_FAULT);
        }
        // no place to save this state but nothing to do anyway
@@ -967,7 +967,7 @@ IA64FAULT vcpu_set_lrr1(VCPU *vcpu, UINT
 IA64FAULT vcpu_set_lrr1(VCPU *vcpu, UINT64 val)
 {
        if (!(val & (1L << 16))) {
-               printf("vcpu_set_lrr0: Unmasked interrupts unsupported\n");
+               printk("vcpu_set_lrr0: Unmasked interrupts unsupported\n");
                return (IA64_ILLOP_FAULT);
        }
        // no place to save this state but nothing to do anyway
@@ -1051,7 +1051,7 @@ void vcpu_safe_set_itm(unsigned long val
 
        local_irq_save(flags);
        while (1) {
-//printf("*** vcpu_safe_set_itm: Setting itm to %lx, itc=%lx\n",val,now);
+//printk("*** vcpu_safe_set_itm: Setting itm to %lx, itc=%lx\n",val,now);
                ia64_set_itm(val);
                if (val > (now = ia64_get_itc())) break;
                val = now + epsilon;
@@ -1071,7 +1071,7 @@ void vcpu_set_next_timer(VCPU *vcpu)
         * but it doesn't matter right now */
 
        if (is_idle_domain(vcpu->domain)) {
-//             printf("****** vcpu_set_next_timer called during idle!!\n");
+//             printk("****** vcpu_set_next_timer called during idle!!\n");
                vcpu_safe_set_itm(s);
                return;
        }
@@ -1091,7 +1091,7 @@ IA64FAULT vcpu_set_itm(VCPU *vcpu, UINT6
        //UINT now = ia64_get_itc();
 
        //if (val < now) val = now + 1000;
-//printf("*** vcpu_set_itm: called with %lx\n",val);
+//printk("*** vcpu_set_itm: called with %lx\n",val);
        PSCBX(vcpu,domain_itm) = val;
        vcpu_set_next_timer(vcpu);
        return (IA64_NO_FAULT);
@@ -1103,8 +1103,8 @@ IA64FAULT vcpu_set_itc(VCPU *vcpu, UINT6
 #ifdef DISALLOW_SETTING_ITC_FOR_NOW
        static int did_print;
        if (!did_print) {
-               printf("vcpu_set_itc: Setting ar.itc is currently disabled\n");
-               printf("(this message is only displayed one)\n");
+               printk("vcpu_set_itc: Setting ar.itc is currently disabled\n");
+               printk("(this message is only displayed one)\n");
                did_print = 1;
        }
 #else
@@ -1117,7 +1117,7 @@ IA64FAULT vcpu_set_itc(VCPU *vcpu, UINT6
 
        local_irq_disable();
        if (olditm) {
-printf("**** vcpu_set_itc(%lx): vitm changed to %lx\n",val,newnow+d);
+printk("**** vcpu_set_itc(%lx): vitm changed to %lx\n",val,newnow+d);
                PSCBX(vcpu,domain_itm) = newnow + d;
        }
        local_cpu_data->itm_next = newnow + x;
@@ -1141,7 +1141,7 @@ IA64FAULT vcpu_get_itm(VCPU *vcpu, UINT6
 IA64FAULT vcpu_get_itm(VCPU *vcpu, UINT64 *pval)
 {
        //FIXME: Implement this
-       printf("vcpu_get_itm: Getting cr.itm is unsupported... continuing\n");
+       printk("vcpu_get_itm: Getting cr.itm is unsupported... continuing\n");
        return (IA64_NO_FAULT);
        //return (IA64_ILLOP_FAULT);
 }
@@ -1149,7 +1149,7 @@ IA64FAULT vcpu_get_itc(VCPU *vcpu, UINT6
 IA64FAULT vcpu_get_itc(VCPU *vcpu, UINT64 *pval)
 {
        //TODO: Implement this
-       printf("vcpu_get_itc: Getting ar.itc is unsupported\n");
+       printk("vcpu_get_itc: Getting ar.itc is unsupported\n");
        return (IA64_ILLOP_FAULT);
 }
 
@@ -1231,7 +1231,7 @@ IA64FAULT vcpu_rfi(VCPU *vcpu)
        psr.ia64_psr.bn = 1;
        //psr.pk = 1;  // checking pkeys shouldn't be a problem but seems broken
        if (psr.ia64_psr.be) {
-               printf("*** DOMAIN TRYING TO TURN ON BIG-ENDIAN!!!\n");
+               printk("*** DOMAIN TRYING TO TURN ON BIG-ENDIAN!!!\n");
                return (IA64_ILLOP_FAULT);
        }
        PSCB(vcpu,incomplete_regframe) = 0; // is this necessary?
@@ -1297,7 +1297,7 @@ IA64FAULT vcpu_thash(VCPU *vcpu, UINT64 
 
 IA64FAULT vcpu_ttag(VCPU *vcpu, UINT64 vadr, UINT64 *padr)
 {
-       printf("vcpu_ttag: ttag instruction unsupported\n");
+       printk("vcpu_ttag: ttag instruction unsupported\n");
        return (IA64_ILLOP_FAULT);
 }
 
@@ -1601,7 +1601,7 @@ IA64FAULT vcpu_tpa(VCPU *vcpu, UINT64 va
 
 IA64FAULT vcpu_tak(VCPU *vcpu, UINT64 vadr, UINT64 *key)
 {
-       printf("vcpu_tak: tak instruction unsupported\n");
+       printk("vcpu_tak: tak instruction unsupported\n");
        return (IA64_ILLOP_FAULT);
        // HACK ALERT: tak does a thash for now
        //return vcpu_thash(vcpu,vadr,key);
@@ -1652,7 +1652,7 @@ IA64FAULT vcpu_set_pmc(VCPU *vcpu, UINT6
        // TODO: Should set Logical CPU state, not just physical
        // NOTE: Writes to unimplemented PMC registers are discarded
 #ifdef DEBUG_PFMON
-printf("vcpu_set_pmc(%x,%lx)\n",reg,val);
+printk("vcpu_set_pmc(%x,%lx)\n",reg,val);
 #endif
        ia64_set_pmc(reg,val);
        return (IA64_NO_FAULT);
@@ -1663,7 +1663,7 @@ IA64FAULT vcpu_set_pmd(VCPU *vcpu, UINT6
        // TODO: Should set Logical CPU state, not just physical
        // NOTE: Writes to unimplemented PMD registers are discarded
 #ifdef DEBUG_PFMON
-printf("vcpu_set_pmd(%x,%lx)\n",reg,val);
+printk("vcpu_set_pmd(%x,%lx)\n",reg,val);
 #endif
        ia64_set_pmd(reg,val);
        return (IA64_NO_FAULT);
@@ -1674,7 +1674,7 @@ IA64FAULT vcpu_get_pmc(VCPU *vcpu, UINT6
        // NOTE: Reads from unimplemented PMC registers return zero
        UINT64 val = (UINT64)ia64_get_pmc(reg);
 #ifdef DEBUG_PFMON
-printf("%lx=vcpu_get_pmc(%x)\n",val,reg);
+printk("%lx=vcpu_get_pmc(%x)\n",val,reg);
 #endif
        *pval = val;
        return (IA64_NO_FAULT);
@@ -1685,7 +1685,7 @@ IA64FAULT vcpu_get_pmd(VCPU *vcpu, UINT6
        // NOTE: Reads from unimplemented PMD registers return zero
        UINT64 val = (UINT64)ia64_get_pmd(reg);
 #ifdef DEBUG_PFMON
-printf("%lx=vcpu_get_pmd(%x)\n",val,reg);
+printk("%lx=vcpu_get_pmd(%x)\n",val,reg);
 #endif
        *pval = val;
        return (IA64_NO_FAULT);
@@ -1914,7 +1914,7 @@ IA64FAULT vcpu_itr_d(VCPU *vcpu, UINT64 
        vcpu_purge_tr_entry(&PSCBX(vcpu, dtlb));
 
        trp = &PSCBX(vcpu,dtrs[slot]);
-//printf("***** itr.d: setting slot %d: ifa=%p\n",slot,ifa);
+//printk("***** itr.d: setting slot %d: ifa=%p\n",slot,ifa);
        vcpu_set_tr_entry(trp,pte,itir,ifa);
        vcpu_quick_region_set(PSCBX(vcpu,dtr_regions),ifa);
 
@@ -1940,7 +1940,7 @@ IA64FAULT vcpu_itr_i(VCPU *vcpu, UINT64 
        vcpu_purge_tr_entry(&PSCBX(vcpu, itlb));
 
        trp = &PSCBX(vcpu,itrs[slot]);
-//printf("***** itr.i: setting slot %d: ifa=%p\n",slot,ifa);
+//printk("***** itr.i: setting slot %d: ifa=%p\n",slot,ifa);
        vcpu_set_tr_entry(trp,pte,itir,ifa);
        vcpu_quick_region_set(PSCBX(vcpu,itr_regions),ifa);
 
@@ -2020,7 +2020,7 @@ void vcpu_itc_no_srlz(VCPU *vcpu, UINT64
                // FIXME: this is dangerous... vhpt_flush_address ensures these
                // addresses never get flushed.  More work needed if this
                // ever happens.
-//printf("vhpt_insert(%p,%p,%p)\n",vaddr,pte,1L<<logps);
+//printk("vhpt_insert(%p,%p,%p)\n",vaddr,pte,1L<<logps);
                if (logps > PAGE_SHIFT) vhpt_multiple_insert(vaddr,pte,logps);
                else vhpt_insert(vaddr,pte,logps<<2);
        }
@@ -2147,7 +2147,7 @@ IA64FAULT vcpu_ptc_ga(VCPU *vcpu,UINT64 
        // FIXME: validate not flushing Xen addresses
        // if (Xen address) return(IA64_ILLOP_FAULT);
        // FIXME: ??breaks if domain PAGE_SIZE < Xen PAGE_SIZE
-//printf("######## vcpu_ptc_ga(%p,%p) ##############\n",vadr,addr_range);
+//printk("######## vcpu_ptc_ga(%p,%p) ##############\n",vadr,addr_range);
 
        check_xen_space_overlap ("ptc_ga", vadr, addr_range);
 
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/vhpt.c
--- a/xen/arch/ia64/xen/vhpt.c  Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/vhpt.c  Mon Oct 23 14:42:52 2006 +0100
@@ -87,7 +87,7 @@ void vhpt_multiple_insert(unsigned long 
                //  only a few times/second, so OK for now.
                //  An alternate solution would be to just insert the one
                //  16KB in the vhpt (but with the full mapping)?
-               //printf("vhpt_multiple_insert: logps-PAGE_SHIFT==%d,"
+               //printk("vhpt_multiple_insert: logps-PAGE_SHIFT==%d,"
                        //"va=%p, pa=%p, pa-masked=%p\n",
                        //logps-PAGE_SHIFT,vaddr,pte&_PFN_MASK,
                        //(pte&_PFN_MASK)&~mask);
@@ -120,7 +120,7 @@ void vhpt_init(void)
                panic("vhpt_init: bad VHPT alignment!\n");
        __get_cpu_var(vhpt_paddr) = paddr;
        __get_cpu_var(vhpt_pend) = paddr + (1 << VHPT_SIZE_LOG2) - 1;
-       printf("vhpt_init: vhpt paddr=0x%lx, end=0x%lx\n",
+       printk("vhpt_init: vhpt paddr=0x%lx, end=0x%lx\n",
                paddr, __get_cpu_var(vhpt_pend));
        pte = pte_val(pfn_pte(paddr >> PAGE_SHIFT, PAGE_KERNEL));
        vhpt_map(pte);
@@ -209,7 +209,7 @@ void domain_flush_vtlb_range (struct dom
 #if 0
        // this only seems to occur at shutdown, but it does occur
        if ((!addr_range) || addr_range & (addr_range - 1)) {
-               printf("vhpt_flush_address: weird range, spinning...\n");
+               printk("vhpt_flush_address: weird range, spinning...\n");
                while(1);
        }
 #endif
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/xenmisc.c
--- a/xen/arch/ia64/xen/xenmisc.c       Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/xenmisc.c       Mon Oct 23 14:42:52 2006 +0100
@@ -179,13 +179,13 @@ void panic_domain(struct pt_regs *regs, 
        char buf[256];
        struct vcpu *v = current;
 
-       printf("$$$$$ PANIC in domain %d (k6=0x%lx): ",
+       printk("$$$$$ PANIC in domain %d (k6=0x%lx): ",
                v->domain->domain_id,
                __get_cpu_var(cpu_kr)._kr[IA64_KR_CURRENT]);
        va_start(args, fmt);
        (void)vsnprintf(buf, sizeof(buf), fmt, args);
        va_end(args);
-       printf(buf);
+       printk(buf);
        if (regs) show_registers(regs);
        if (regs) {
                debugger_trap_fatal(0 /* don't care */, regs);
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/xensetup.c
--- a/xen/arch/ia64/xen/xensetup.c      Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/xensetup.c      Mon Oct 23 14:42:52 2006 +0100
@@ -386,13 +386,13 @@ void start_kernel(void)
     /* first find highest page frame number */
     max_page = 0;
     efi_memmap_walk(find_max_pfn, &max_page);
-    printf("find_memory: efi_memmap_walk returns max_page=%lx\n",max_page);
+    printk("find_memory: efi_memmap_walk returns max_page=%lx\n",max_page);
     efi_print();
 
     heap_start = memguard_init(ia64_imva(&_end));
-    printf("Before heap_start: %p\n", heap_start);
+    printk("Before heap_start: %p\n", heap_start);
     heap_start = __va(init_boot_allocator(__pa(heap_start)));
-    printf("After heap_start: %p\n", heap_start);
+    printk("After heap_start: %p\n", heap_start);
 
     efi_memmap_walk(filter_rsvd_memory, init_boot_pages);
     efi_memmap_walk(xen_count_pages, &nr_pages);
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/xen/xentime.c
--- a/xen/arch/ia64/xen/xentime.c       Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/xen/xentime.c       Mon Oct 23 14:42:52 2006 +0100
@@ -116,7 +116,7 @@ xen_timer_interrupt (int irq, void *dev_
 #ifdef HEARTBEAT_FREQ
        static long count = 0;
        if (!(++count & ((HEARTBEAT_FREQ*1024)-1))) {
-               printf("Heartbeat... iip=%p\n", /*",psr.i=%d,pend=%d\n", */
+               printk("Heartbeat... iip=%p\n", /*",psr.i=%d,pend=%d\n", */
                        regs->cr_iip /*,
                        !current->vcpu_info->evtchn_upcall_mask,
                        VCPU(current,pending_interruption) */);
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/powerpc/backtrace.c
--- a/xen/arch/powerpc/backtrace.c      Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/powerpc/backtrace.c      Mon Oct 23 14:42:52 2006 +0100
@@ -93,13 +93,13 @@ static void xmon_print_symbol(unsigned l
        const char *name = NULL;
        unsigned long offset, size;
 
-       printf(REG, address);
+       printk(REG, address);
 
     name = symbols_lookup(address, &size, &offset, namebuf);
        if (name) {
-               printf("%s%s+%#lx/%#lx", mid, name, offset, size);
+               printk("%s%s+%#lx/%#lx", mid, name, offset, size);
        }
-       printf("%s", after);
+       printk("%s", after);
 }
 
 static void backtrace(
@@ -114,13 +114,13 @@ static void backtrace(
        do {
                if (sp > xenheap_phys_end) {
                        if (sp != 0)
-                               printf("SP (%lx) is not in xen space\n", sp);
+                               printk("SP (%lx) is not in xen space\n", sp);
                        break;
                }
 
                if (!mread(sp + LRSAVE_OFFSET, &ip, sizeof(unsigned long))
                    || !mread(sp, &newsp, sizeof(unsigned long))) {
-                       printf("Couldn't read stack frame at %lx\n", sp);
+                       printk("Couldn't read stack frame at %lx\n", sp);
                        break;
                }
 
@@ -147,17 +147,17 @@ static void backtrace(
                                printip = 0;
                        } else if (lr < xenheap_phys_end
                        && !(fnstart <= lr && lr < fnend)) {
-                               printf("[link register   ] ");
+                               printk("[link register   ] ");
                                xmon_print_symbol(lr, " ", "\n");
                        }
                        if (printip) {
-                               printf("["REG"] ", sp);
+                               printk("["REG"] ", sp);
                                xmon_print_symbol(ip, " ", " (unreliable)\n");
                        }
                        pc = lr = 0;
 
                } else {
-                       printf("["REG"] ", sp);
+                       printk("["REG"] ", sp);
                        xmon_print_symbol(ip, " ", "\n");
                }
 
@@ -167,11 +167,11 @@ static void backtrace(
                    && marker == REG_FRAME_MARKER) {
                        if (mread(sp + REGS_OFFSET, &regs, sizeof(regs))
                            != sizeof(regs)) {
-                               printf("Couldn't read registers at %lx\n",
+                               printk("Couldn't read registers at %lx\n",
                                       sp + REGS_OFFSET);
                                break;
                        }
-            printf("--- Exception: %x %s at ", regs.entry_vector,
+            printk("--- Exception: %x %s at ", regs.entry_vector,
                               getvecname(TRAP(&regs)));
                        pc = regs.pc;
                        lr = regs.lr;
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/powerpc/domain.c
--- a/xen/arch/powerpc/domain.c Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/powerpc/domain.c Mon Oct 23 14:42:52 2006 +0100
@@ -97,14 +97,14 @@ void arch_domain_destroy(struct domain *
 
 void machine_halt(void)
 {
-    printf("machine_halt called: spinning....\n");
+    printk("machine_halt called: spinning....\n");
     console_start_sync();
     while(1);
 }
 
 void machine_restart(char * __unused)
 {
-    printf("machine_restart called: spinning....\n");
+    printk("machine_restart called: spinning....\n");
     console_start_sync();
     while(1);
 }
@@ -134,7 +134,7 @@ int arch_set_info_guest(struct vcpu *v, 
 { 
     memcpy(&v->arch.ctxt, &c->user_regs, sizeof(c->user_regs));
 
-    printf("Domain[%d].%d: initializing\n",
+    printk("Domain[%d].%d: initializing\n",
            v->domain->domain_id, v->vcpu_id);
 
     if (v->domain->arch.htab.order == 0)
@@ -186,7 +186,7 @@ void context_switch(struct vcpu *prev, s
     unsigned int cpu = smp_processor_id();
 
 #if 0
-    printf("%s: dom %x to dom %x\n", __func__, prev->domain->domain_id,
+    printk("%s: dom %x to dom %x\n", __func__, prev->domain->domain_id,
             next->domain->domain_id);
 #endif
 
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/powerpc/of-devwalk.c
--- a/xen/arch/powerpc/of-devwalk.c     Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/powerpc/of-devwalk.c     Mon Oct 23 14:42:52 2006 +0100
@@ -35,7 +35,7 @@ void ofd_prop_print(
     if ( path[0] == '/' && path[1] == '\0' ) {
         path = "";
     }
-    printf("%s: %s/%s: 0x%lx\n", head, path,  name, sz);
+    printk("%s: %s/%s: 0x%lx\n", head, path,  name, sz);
 
 #define DEBUG_PROP
 #ifdef DEBUG_PROP
@@ -56,24 +56,24 @@ void ofd_prop_print(
     }
 
     if ( isstr > 0 ) {
-        printf("%s: \t%s\n", head, b);
+        printk("%s: \t%s\n", head, b);
     } else if ( sz != 0 ) {
-        printf("%s: \t0x", head);
+        printk("%s: \t0x", head);
 
         for ( i = 0; i < sz; i++ ) {
             if ( (i % 4) == 0 && i != 0 ) {
                 if ( (i % 16) == 0 && i != 0 ) {
-                    printf("\n%s: \t0x", head);
+                    printk("\n%s: \t0x", head);
                 } else {
-                    printf(" 0x");
+                    printk(" 0x");
                 }
             }
             if (b[i] < 0x10) {
-                printf("0");
+                printk("0");
             }
-            printf("%x", b[i]);
+            printk("%x", b[i]);
         }
-        printf("\n");
+        printk("\n");
     }
 #else
     (void)prop;
@@ -95,7 +95,7 @@ void ofd_dump_props(void *mem, ofdn_t n,
     }
 
     if (dump & OFD_DUMP_NAMES) {
-        printf("of_walk: %s: phandle 0x%x\n", path, n);
+        printk("of_walk: %s: phandle 0x%x\n", path, n);
     }
 
     p = ofd_nextprop(mem, n, NULL, name);
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/powerpc/powerpc64/domain.c
--- a/xen/arch/powerpc/powerpc64/domain.c       Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/powerpc/powerpc64/domain.c       Mon Oct 23 14:42:52 2006 +0100
@@ -112,7 +112,7 @@ void save_segments(struct vcpu *v)
         slb_entry[i].slb_esid = esid;
 #ifdef SLB_DEBUG
         if (vsid != 0) {
-            printf("%s: DOM[0x%x]: S%02d: 0x%016lx 0x%016lx\n",
+            printk("%s: DOM[0x%x]: S%02d: 0x%016lx 0x%016lx\n",
                     __func__, v->domain->domain_id, i, vsid, esid);
         }
 #endif
@@ -146,7 +146,7 @@ void load_segments(struct vcpu *v)
 
 #ifdef SLB_DEBUG
         if (vsid != 0) {
-            printf("%s: DOM[0x%x]: R%02d: 0x%016lx 0x%016lx\n",
+            printk("%s: DOM[0x%x]: R%02d: 0x%016lx 0x%016lx\n",
                     __func__, v->domain->domain_id, i, vsid, esid);
         }
 #endif
@@ -173,6 +173,6 @@ void dump_segments(int valid)
 
         if (valid && !(esid & SLB_ESID_VALID))
             continue;
-        printf("S%02d: 0x%016lx 0x%016lx\n", i, vsid, esid);
+        printk("S%02d: 0x%016lx 0x%016lx\n", i, vsid, esid);
     }
 }
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/x86/boot/x86_32.S
--- a/xen/arch/x86/boot/x86_32.S        Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/x86/boot/x86_32.S        Mon Oct 23 14:42:52 2006 +0100
@@ -185,7 +185,7 @@ ignore_int:
         mov     %eax,%ds
         mov     %eax,%es
         pushl   $int_msg
-        call    printf
+        call    printk
 1:      jmp     1b
 
 /*** STACK LOCATION ***/
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/x86/boot/x86_64.S
--- a/xen/arch/x86/boot/x86_64.S        Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/x86/boot/x86_64.S        Mon Oct 23 14:42:52 2006 +0100
@@ -186,7 +186,7 @@ ignore_int:
         cld
         leaq    int_msg(%rip),%rdi
         xorl    %eax,%eax
-        call    printf
+        call    printk
 1:      jmp     1b
 
 
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/x86/hvm/hvm.c
--- a/xen/arch/x86/hvm/hvm.c    Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/x86/hvm/hvm.c    Mon Oct 23 14:42:52 2006 +0100
@@ -248,7 +248,7 @@ void hvm_do_resume(struct vcpu *v)
     case STATE_INVALID:
         break;
     default:
-        printf("Weird HVM iorequest state %d.\n", p->state);
+        printk("Weird HVM iorequest state %d.\n", p->state);
         domain_crash(v->domain);
     }
 }
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/x86/hvm/io.c
--- a/xen/arch/x86/hvm/io.c     Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/x86/hvm/io.c     Mon Oct 23 14:42:52 2006 +0100
@@ -723,7 +723,7 @@ void hvm_io_assist(struct vcpu *v)
     vio = get_vio(v->domain, v->vcpu_id);
 
     if ( vio == 0 ) {
-        printf("bad shared page: %lx\n", (unsigned long)vio);
+        printk("bad shared page: %lx\n", (unsigned long)vio);
         domain_crash_synchronous();
     }
 
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/x86/hvm/platform.c
--- a/xen/arch/x86/hvm/platform.c       Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/x86/hvm/platform.c       Mon Oct 23 14:42:52 2006 +0100
@@ -741,7 +741,8 @@ void send_pio_req(unsigned long port, un
     ioreq_t *p;
 
     if ( size == 0 || count == 0 ) {
-        printf("null pio request? port %lx, count %lx, size %d, value %lx, dir 
%d, pvalid %d.\n",
+        printk("null pio request? port %lx, count %lx, "
+               "size %d, value %lx, dir %d, pvalid %d.\n",
                port, count, size, value, dir, pvalid);
     }
 
@@ -794,7 +795,8 @@ static void send_mmio_req(unsigned char 
     ioreq_t *p;
 
     if ( size == 0 || count == 0 ) {
-        printf("null mmio request? type %d, gpa %lx, count %lx, size %d, value 
%lx, dir %d, pvalid %d.\n",
+        printk("null mmio request? type %d, gpa %lx, "
+               "count %lx, size %d, value %lx, dir %d, pvalid %d.\n",
                type, gpa, count, size, value, dir, pvalid);
     }
 
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/x86/hvm/svm/intr.c
--- a/xen/arch/x86/hvm/svm/intr.c       Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/x86/hvm/svm/intr.c       Mon Oct 23 14:42:52 2006 +0100
@@ -59,7 +59,7 @@ static inline int svm_inject_extint(stru
     intr.fields.prio = 0xF;
     intr.fields.ign_tpr = 1;
     vmcb->vintr = intr;
-//  printf( "IRQ = %d\n", trap );
+
     return 0;
 }
     
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/x86/hvm/svm/svm.c
--- a/xen/arch/x86/hvm/svm/svm.c        Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/x86/hvm/svm/svm.c        Mon Oct 23 14:42:52 2006 +0100
@@ -1021,7 +1021,7 @@ static void svm_do_general_protection_fa
     error_code = vmcb->exitinfo1;
 
     if (vmcb->idtr.limit == 0) {
-        printf("Huh? We got a GP Fault with an invalid IDTR!\n");
+        printk("Huh? We got a GP Fault with an invalid IDTR!\n");
         svm_dump_vmcb(__func__, vmcb);
         svm_dump_regs(__func__, regs);
         svm_dump_inst(vmcb->rip);
@@ -2295,7 +2295,7 @@ static int svm_do_vmmcall(struct vcpu *v
         /* VMMCALL sanity check */
         if ( vmcb->cpl > get_vmmcall_cpl(regs->edi) )
         {
-            printf("VMMCALL CPL check failed\n");
+            printk("VMMCALL CPL check failed\n");
             return -1;
         }
 
@@ -2305,7 +2305,7 @@ static int svm_do_vmmcall(struct vcpu *v
         case VMMCALL_RESET_TO_REALMODE:
             if ( svm_do_vmmcall_reset_to_realmode(v, regs) )
             {
-                printf("svm_do_vmmcall_reset_to_realmode() failed\n");
+                printk("svm_do_vmmcall_reset_to_realmode() failed\n");
                 return -1;
             }
             /* since we just reset the VMCB, return without adjusting
@@ -2313,7 +2313,7 @@ static int svm_do_vmmcall(struct vcpu *v
             return 0;
 
         case VMMCALL_DEBUG:
-            printf("DEBUG features not implemented yet\n");
+            printk("DEBUG features not implemented yet\n");
             break;
         default:
             break;
@@ -2344,16 +2344,16 @@ void svm_dump_inst(unsigned long eip)
     if (hvm_copy_from_guest_virt(opcode, ptr, sizeof(opcode)) == 0)
         len = sizeof(opcode);
 
-    printf("Code bytes around(len=%d) %lx:", len, eip);
+    printk("Code bytes around(len=%d) %lx:", len, eip);
     for (i = 0; i < len; i++)
     {
         if ((i & 0x0f) == 0)
-            printf("\n%08lx:", ptr+i);
-
-        printf("%02x ", opcode[i]);
-    }
-
-    printf("\n");
+            printk("\n%08lx:", ptr+i);
+
+        printk("%02x ", opcode[i]);
+    }
+
+    printk("\n");
 }
 
 
@@ -2363,7 +2363,7 @@ void svm_dump_regs(const char *from, str
     struct vmcb_struct *vmcb = v->arch.hvm_svm.vmcb;
     unsigned long pt = v->arch.hvm_vcpu.hw_cr3;
 
-    printf("%s: guest registers from %s:\n", __func__, from);
+    printk("%s: guest registers from %s:\n", __func__, from);
 #if defined (__x86_64__)
     printk("rax: %016lx   rbx: %016lx   rcx: %016lx\n",
            regs->rax, regs->rbx, regs->rcx);
@@ -2378,15 +2378,15 @@ void svm_dump_regs(const char *from, str
     printk("r15: %016lx   cr0: %016lx   cr3: %016lx\n",
            regs->r15, v->arch.hvm_svm.cpu_shadow_cr0, vmcb->cr3);
 #else
-    printf("eax: %08x, ebx: %08x, ecx: %08x, edx: %08x\n", 
+    printk("eax: %08x, ebx: %08x, ecx: %08x, edx: %08x\n", 
            regs->eax, regs->ebx, regs->ecx, regs->edx);
-    printf("edi: %08x, esi: %08x, ebp: %08x, esp: %08x\n", 
+    printk("edi: %08x, esi: %08x, ebp: %08x, esp: %08x\n", 
            regs->edi, regs->esi, regs->ebp, regs->esp);
-    printf("%s: guest cr0: %lx\n", __func__, 
+    printk("%s: guest cr0: %lx\n", __func__, 
            v->arch.hvm_svm.cpu_shadow_cr0);
-    printf("guest CR3 = %llx\n", vmcb->cr3);
+    printk("guest CR3 = %llx\n", vmcb->cr3);
 #endif
-    printf("%s: pt = %lx\n", __func__, pt);
+    printk("%s: pt = %lx\n", __func__, pt);
 }
 
 
@@ -2395,12 +2395,12 @@ void svm_dump_host_regs(const char *from
     struct vcpu *v = current;
     unsigned long pt = pt = pagetable_get_paddr(v->arch.monitor_table);
     unsigned long cr3, cr0;
-    printf("Host registers at %s\n", from);
+    printk("Host registers at %s\n", from);
 
     __asm__ __volatile__ ("\tmov %%cr0,%0\n"
                           "\tmov %%cr3,%1\n"
                           : "=r" (cr0), "=r"(cr3));
-    printf("%s: pt = %lx, cr3 = %lx, cr0 = %lx\n", __func__, pt, cr3, cr0);
+    printk("%s: pt = %lx, cr3 = %lx, cr0 = %lx\n", __func__, pt, cr3, cr0);
 }
 
 #ifdef SVM_EXTRA_DEBUG
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/x86/hvm/svm/vmcb.c
--- a/xen/arch/x86/hvm/svm/vmcb.c       Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/x86/hvm/svm/vmcb.c       Mon Oct 23 14:42:52 2006 +0100
@@ -408,7 +408,7 @@ void svm_do_launch(struct vcpu *v)
 
 static void svm_dump_sel(char *name, segment_selector_t *s)
 {
-    printf("%s: sel=0x%04x, attr=0x%04x, limit=0x%08x, base=0x%016llx\n", 
+    printk("%s: sel=0x%04x, attr=0x%04x, limit=0x%08x, base=0x%016llx\n", 
            name, s->sel, s->attributes.bytes, s->limit,
            (unsigned long long)s->base);
 }
@@ -416,50 +416,50 @@ static void svm_dump_sel(char *name, seg
 
 void svm_dump_vmcb(const char *from, struct vmcb_struct *vmcb)
 {
-    printf("Dumping guest's current state at %s...\n", from);
-    printf("Size of VMCB = %d, address = %p\n", 
+    printk("Dumping guest's current state at %s...\n", from);
+    printk("Size of VMCB = %d, address = %p\n", 
             (int) sizeof(struct vmcb_struct), vmcb);
 
-    printf("cr_intercepts = 0x%08x dr_intercepts = 0x%08x "
+    printk("cr_intercepts = 0x%08x dr_intercepts = 0x%08x "
            "exception_intercepts = 0x%08x\n", 
            vmcb->cr_intercepts, vmcb->dr_intercepts, 
            vmcb->exception_intercepts);
-    printf("general1_intercepts = 0x%08x general2_intercepts = 0x%08x\n", 
+    printk("general1_intercepts = 0x%08x general2_intercepts = 0x%08x\n", 
            vmcb->general1_intercepts, vmcb->general2_intercepts);
-    printf("iopm_base_pa = %016llx msrpm_base_pa = 0x%016llx tsc_offset = "
+    printk("iopm_base_pa = %016llx msrpm_base_pa = 0x%016llx tsc_offset = "
             "0x%016llx\n", 
            (unsigned long long) vmcb->iopm_base_pa,
            (unsigned long long) vmcb->msrpm_base_pa,
            (unsigned long long) vmcb->tsc_offset);
-    printf("tlb_control = 0x%08x vintr = 0x%016llx interrupt_shadow = "
+    printk("tlb_control = 0x%08x vintr = 0x%016llx interrupt_shadow = "
             "0x%016llx\n", vmcb->tlb_control,
            (unsigned long long) vmcb->vintr.bytes,
            (unsigned long long) vmcb->interrupt_shadow);
-    printf("exitcode = 0x%016llx exitintinfo = 0x%016llx\n", 
+    printk("exitcode = 0x%016llx exitintinfo = 0x%016llx\n", 
            (unsigned long long) vmcb->exitcode,
            (unsigned long long) vmcb->exitintinfo.bytes);
-    printf("exitinfo1 = 0x%016llx exitinfo2 = 0x%016llx \n",
+    printk("exitinfo1 = 0x%016llx exitinfo2 = 0x%016llx \n",
            (unsigned long long) vmcb->exitinfo1,
            (unsigned long long) vmcb->exitinfo2);
-    printf("np_enable = 0x%016llx guest_asid = 0x%03x\n", 
+    printk("np_enable = 0x%016llx guest_asid = 0x%03x\n", 
            (unsigned long long) vmcb->np_enable, vmcb->guest_asid);
-    printf("cpl = %d efer = 0x%016llx star = 0x%016llx lstar = 0x%016llx\n", 
+    printk("cpl = %d efer = 0x%016llx star = 0x%016llx lstar = 0x%016llx\n", 
            vmcb->cpl, (unsigned long long) vmcb->efer,
            (unsigned long long) vmcb->star, (unsigned long long) vmcb->lstar);
-    printf("CR0 = 0x%016llx CR2 = 0x%016llx\n",
+    printk("CR0 = 0x%016llx CR2 = 0x%016llx\n",
            (unsigned long long) vmcb->cr0, (unsigned long long) vmcb->cr2);
-    printf("CR3 = 0x%016llx CR4 = 0x%016llx\n", 
+    printk("CR3 = 0x%016llx CR4 = 0x%016llx\n", 
            (unsigned long long) vmcb->cr3, (unsigned long long) vmcb->cr4);
-    printf("RSP = 0x%016llx  RIP = 0x%016llx\n", 
+    printk("RSP = 0x%016llx  RIP = 0x%016llx\n", 
            (unsigned long long) vmcb->rsp, (unsigned long long) vmcb->rip);
-    printf("RAX = 0x%016llx  RFLAGS=0x%016llx\n",
+    printk("RAX = 0x%016llx  RFLAGS=0x%016llx\n",
            (unsigned long long) vmcb->rax, (unsigned long long) vmcb->rflags);
-    printf("DR6 = 0x%016llx, DR7 = 0x%016llx\n", 
+    printk("DR6 = 0x%016llx, DR7 = 0x%016llx\n", 
            (unsigned long long) vmcb->dr6, (unsigned long long) vmcb->dr7);
-    printf("CSTAR = 0x%016llx SFMask = 0x%016llx\n",
+    printk("CSTAR = 0x%016llx SFMask = 0x%016llx\n",
            (unsigned long long) vmcb->cstar, 
            (unsigned long long) vmcb->sfmask);
-    printf("KernGSBase = 0x%016llx PAT = 0x%016llx \n", 
+    printk("KernGSBase = 0x%016llx PAT = 0x%016llx \n", 
            (unsigned long long) vmcb->kerngsbase,
            (unsigned long long) vmcb->g_pat);
     
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/x86/hvm/vmx/vmx.c
--- a/xen/arch/x86/hvm/vmx/vmx.c        Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/x86/hvm/vmx/vmx.c        Mon Oct 23 14:42:52 2006 +0100
@@ -1087,7 +1087,7 @@ static int check_for_null_selector(unsig
     memset(inst, 0, MAX_INST_LEN);
     if ( inst_copy_from_guest(inst, eip, inst_len) != inst_len )
     {
-        printf("check_for_null_selector: get guest instruction failed\n");
+        printk("check_for_null_selector: get guest instruction failed\n");
         domain_crash_synchronous();
     }
 
@@ -1470,7 +1470,7 @@ static int vmx_assist(struct vcpu *v, in
     }
 
  error:
-    printf("Failed to transfer to vmxassist\n");
+    printk("Failed to transfer to vmxassist\n");
     domain_crash_synchronous();
     return 0;
 }
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/x86/setup.c
--- a/xen/arch/x86/setup.c      Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/x86/setup.c      Mon Oct 23 14:42:52 2006 +0100
@@ -296,7 +296,7 @@ void __init __start_xen(multiboot_info_t
 
     init_console();
 
-    printf("Command line: %s\n", cmdline);
+    printk("Command line: %s\n", cmdline);
 
     /* Check that we have at least one Multiboot module. */
     if ( !(mbi->flags & MBI_MODULES) || (mbi->mods_count == 0) )
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/x86/x86_32/entry.S
--- a/xen/arch/x86/x86_32/entry.S       Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/x86/x86_32/entry.S       Mon Oct 23 14:42:52 2006 +0100
@@ -398,7 +398,7 @@ domain_crash_synchronous_string:
 
 domain_crash_synchronous:
         pushl $domain_crash_synchronous_string
-        call  printf
+        call  printk
         jmp   __domain_crash_synchronous
 
         ALIGN
diff -r f5d179bcad70 -r 29b02d929b7e 
xen/arch/x86/x86_32/supervisor_mode_kernel.S
--- a/xen/arch/x86/x86_32/supervisor_mode_kernel.S      Mon Oct 23 14:19:14 
2006 +0100
+++ b/xen/arch/x86/x86_32/supervisor_mode_kernel.S      Mon Oct 23 14:42:52 
2006 +0100
@@ -141,5 +141,5 @@ domain_crash_synchronous_string:
 
 domain_crash_synchronous:
         pushl $domain_crash_synchronous_string
-        call  printf
+        call  printk
         jmp   __domain_crash_synchronous
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/x86/x86_64/entry.S
--- a/xen/arch/x86/x86_64/entry.S       Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/x86/x86_64/entry.S       Mon Oct 23 14:42:52 2006 +0100
@@ -328,7 +328,7 @@ domain_crash_synchronous:
         # printk(domain_crash_synchronous_string)
         leaq  domain_crash_synchronous_string(%rip),%rdi
         xorl  %eax,%eax
-        call  printf
+        call  printk
         jmp  __domain_crash_synchronous
 
         ALIGN
diff -r f5d179bcad70 -r 29b02d929b7e xen/common/sched_sedf.c
--- a/xen/common/sched_sedf.c   Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/common/sched_sedf.c   Mon Oct 23 14:42:52 2006 +0100
@@ -1190,10 +1190,10 @@ static void sedf_dump_domain(struct vcpu
     
 #ifdef SEDF_STATS
     if ( EDOM_INFO(d)->block_time_tot != 0 )
-        printf(" pen=%"PRIu64"%%", (EDOM_INFO(d)->penalty_time_tot * 100) /
+        printk(" pen=%"PRIu64"%%", (EDOM_INFO(d)->penalty_time_tot * 100) /
                EDOM_INFO(d)->block_time_tot);
     if ( EDOM_INFO(d)->block_tot != 0 )
-        printf("\n   blks=%u sh=%u (%u%%) (shc=%u (%u%%) shex=%i "\
+        printk("\n   blks=%u sh=%u (%u%%) (shc=%u (%u%%) shex=%i "\
                "shexsl=%i) l=%u (%u%%) avg: b=%"PRIu64" p=%"PRIu64"",
                EDOM_INFO(d)->block_tot, EDOM_INFO(d)->short_block_tot,
                (EDOM_INFO(d)->short_block_tot * 100) 
@@ -1206,7 +1206,7 @@ static void sedf_dump_domain(struct vcpu
                (EDOM_INFO(d)->block_time_tot) / EDOM_INFO(d)->block_tot,
                (EDOM_INFO(d)->penalty_time_tot) / EDOM_INFO(d)->block_tot);
 #endif
-    printf("\n");
+    printk("\n");
 }
 
 
diff -r f5d179bcad70 -r 29b02d929b7e xen/drivers/char/console.c
--- a/xen/drivers/char/console.c        Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/drivers/char/console.c        Mon Oct 23 14:42:52 2006 +0100
@@ -294,7 +294,7 @@ static inline void __putstr(const char *
     }
 }
 
-void printf(const char *fmt, ...)
+void printk(const char *fmt, ...)
 {
     static char   buf[1024];
     static int    start_of_line = 1;
diff -r f5d179bcad70 -r 29b02d929b7e xen/include/asm-ia64/config.h
--- a/xen/include/asm-ia64/config.h     Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/include/asm-ia64/config.h     Mon Oct 23 14:42:52 2006 +0100
@@ -232,7 +232,7 @@ extern unsigned long loops_per_jiffy;
 extern unsigned long loops_per_jiffy;
 extern char saved_command_line[];
 struct screen_info { };
-#define seq_printf(a,b...) printf(b)
+#define seq_printf(a,b...) printk(b)
 //#define CONFIG_BLK_DEV_INITRD // needed to reserve memory for domain0
 
 #define CONFIG_SHADOW  1
diff -r f5d179bcad70 -r 29b02d929b7e xen/include/asm-ia64/vcpu.h
--- a/xen/include/asm-ia64/vcpu.h       Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/include/asm-ia64/vcpu.h       Mon Oct 23 14:42:52 2006 +0100
@@ -200,7 +200,7 @@ vcpu_get_next_timer_ns(VCPU *vcpu)
     return vcpu_get_next_timer_ns;
 }
 
-#define verbose(a...) do {if (vcpu_verbose) printf(a);} while(0)
+#define verbose(a...) do {if (vcpu_verbose) printk(a);} while(0)
 
 //#define vcpu_quick_region_check(_tr_regions,_ifa) 1
 #define vcpu_quick_region_check(_tr_regions,_ifa)           \
diff -r f5d179bcad70 -r 29b02d929b7e xen/include/xen/lib.h
--- a/xen/include/xen/lib.h     Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/include/xen/lib.h     Mon Oct 23 14:42:52 2006 +0100
@@ -51,8 +51,7 @@ extern void debugtrace_printk(const char
 
 /* Allows us to use '%p' as general-purpose machine-word format char. */
 #define _p(_x) ((void *)(unsigned long)(_x))
-#define printk(_f , _a...) printf( _f , ## _a )
-extern void printf(const char *format, ...)
+extern void printk(const char *format, ...)
     __attribute__ ((format (printf, 1, 2)));
 extern void panic(const char *format, ...)
     __attribute__ ((format (printf, 1, 2)));

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.
diff -r f5d179bcad70 -r 29b02d929b7e xen/arch/ia64/vmx/vmx_phy_mode.c
--- a/xen/arch/ia64/vmx/vmx_phy_mode.c  Mon Oct 23 14:19:14 2006 +0100
+++ b/xen/arch/ia64/vmx/vmx_phy_mode.c  Mon Oct 23 14:42:52 2006 +0100
@@ -265,7 +265,7 @@ switch_mm_mode(VCPU *vcpu, IA64_PSR old_
     perfc_incra(vmx_switch_mm_mode, act);
     switch (act) {
     case SW_V2P:
-//        printf("V -> P mode transition: (0x%lx -> 0x%lx)\n",
+//        printk("V -> P mode transition: (0x%lx -> 0x%lx)\n",
 //               old_psr.val, new_psr.val);
         vcpu->arch.old_rsc = regs->ar_rsc;
         switch_to_physical_rid(vcpu);
@@ -277,7 +277,7 @@ switch_mm_mode(VCPU *vcpu, IA64_PSR old_
         vcpu->arch.mode_flags |= GUEST_IN_PHY;
         break;
     case SW_P2V:
-//        printf("P -> V mode transition: (0x%lx -> 0x%lx)\n",
+//        printk("P -> V mode transition: (0x%lx -> 0x%lx)\n",
 //               old_psr.val, new_psr.val);
         switch_to_virtual_rid(vcpu);
         /*
@@ -288,11 +288,11 @@ switch_mm_mode(VCPU *vcpu, IA64_PSR old_
         vcpu->arch.mode_flags &= ~GUEST_IN_PHY;
         break;
     case SW_SELF:
-        printf("Switch to self-0x%lx!!! MM mode doesn't change...\n",
+        printk("Switch to self-0x%lx!!! MM mode doesn't change...\n",
             old_psr.val);
         break;
     case SW_NOP:
 //        printf("No action required for mode transition: (0x%lx -> 0x%lx)\n",
 //               old_psr.val, new_psr.val);
         break;
     default:
@@ -288,11 +288,11 @@ switch_mm_mode(VCPU *vcpu, IA64_PSR old_
         break;
     case SW_NOP:
-//        printf("No action required for mode transition: (0x%lx -> 0x%lx)\n",
+//        printk("No action required for mode transition: (0x%lx -> 0x%lx)\n",
 //               old_psr.val, new_psr.val);
         break;